/*
	callbacks.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>
#include <gtk/gtk.h>

#include "main.h"
#include "interface.h"

/*** callbacks du menu ***/
/** Menu Fichier **/
void OnNew(GtkWidget *pWidget, glda *pData){
	if(pData->save == FALSE){
		if(saveModif(pData) == TRUE){
			pData->pLdaChainee = resetLda(pData->pLdaChainee);
			gtk_list_store_clear(pData->pLda);
			updateNbArtEtPrixTot(pData);
			pData->save = TRUE;
			g_free(pData->fichierLDA);
			pData->fichierLDA = NULL;
		}
	}
	else{
		pData->pLdaChainee = resetLda(pData->pLdaChainee);
		gtk_list_store_clear(pData->pLda);
		updateNbArtEtPrixTot(pData);
		pData->save = TRUE;
		g_free(pData->fichierLDA);
		pData->fichierLDA = NULL;
	}
}

void OnOpen(GtkWidget *pWidget, glda *pData){
	if(pData->save == FALSE){
		if(saveModif(pData) == TRUE){
			openList(pData);
		}
	}
	else{
		openList(pData);
	}
}

void OnSave(GtkWidget *pWidget, glda *pData){
	saveList(pData);
}

void OnSaveAs(GtkWidget *pWidget, glda *pData){
	saveListAs(pData);
}

void OnExport(GtkWidget *pWidget, glda *pData){
	exportList(pData);
}

void OnDestroy(GtkWidget *pWidget, glda *pData){
	if(saveModif(pData) == TRUE){
		/* Arret de la boucle evenementielle */
		gtk_main_quit();
		/*return FALSE;*/
	}
	/*return TRUE;*/
}

gboolean OnQuit(GtkWidget *pWindow, GdkEvent *pEvent, glda *pData){
	if(saveModif(pData) == TRUE){
		/* Arret de la boucle evenementielle */
		gtk_main_quit();
		/*return FALSE;*/
	}
	return TRUE;
}

/** Menu Edition **/
void OnPreferences(GtkWidget *pWidget, glda *pData){
	create_pPreferences(pData);
}

/** Menu aide **/
void OnAbout(GtkWidget *pWidget, glda *pData){
	create_pAbout(pData);
}

/*** callbacks des 3 boutons du milieu ***/
void OnAdd(GtkWidget *pWidget, glda *pData){
	GList *listCat;
	GList *listArt;
	int *tabCat = NULL;
	int *tabArt = NULL;
	int tabArticles[3];
	gint nbSelectedArt;
	int cpt;
	int Id;
	gint NewQuantite;
	gdouble NewPrix;
	gchar *pPrix;
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	listCat = gtk_tree_selection_get_selected_rows(pData->selectCat, NULL);
	listArt = gtk_tree_selection_get_selected_rows(pData->selectArt, NULL);
	
	if(listArt != NULL){
		nbSelectedArt = gtk_tree_selection_count_selected_rows(pData->selectArt);
		tabCat = gtk_tree_path_get_indices(listCat->data);
		
		cpt = 0;
		for(cpt=0;cpt<nbSelectedArt;cpt++){
			tabArt = gtk_tree_path_get_indices(g_list_nth_data(listArt, cpt));
			tabArticles[0] = tabCat[0]+1;
			tabArticles[1] = tabCat[1]+1;
			tabArticles[2] = tabArt[0]+1;
			Id = dejaAjouter(((glda*)pData)->pLdaChainee, tabArticles);
			if(Id == -1){
				pData->pLdaChainee = AjoutArticle(pData->pLdaChainee, 1, tabArticles);
				addArt(pData, tabArticles[0], tabArticles[1], tabArticles[2], 1);
				updateNbArtEtPrixTot(pData);
			}
			else{
				pPath = gtk_tree_path_new_from_indices(Id, -1);
				gtk_tree_model_get_iter((GtkTreeModel*)pData->pLda, &Iter, pPath);
				NewQuantite = mettreAjourQuantite(pData->pLdaChainee, Id, 1);
				
				pPrix = getArticlePriceBySousCategory(pData->pMagasin, tabArticles[0], tabArticles[1], tabArticles[2]);
				NewPrix = strtod(pPrix, NULL)*NewQuantite;
				free(pPrix);
				pPrix = g_strdup_printf("%.2f", NewPrix);
				gtk_list_store_set(pData->pLda, &Iter, PRIX_COLUMN_LDA, pPrix, QUANTITE_COLUMN_LDA, NewQuantite, -1);
				free(pPrix);
				
				updateNbArtEtPrixTot(pData);
				gtk_tree_path_free(pPath);
			}
		}
		pData->save = FALSE;
		free(tabCat);
		free(tabArt);
	}
	
	g_list_free(listCat);
	g_list_free(listArt);
}

void cell_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_text, glda *pData){
	gint position;
	gint NewQuantite;
	gint *tabArticles;
	gdouble NewPrix;
	gchar *pPrix;
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	position = strtol(path, NULL, 10);
	pPath = gtk_tree_path_new_from_string(path);
	gtk_tree_model_get_iter((GtkTreeModel*)pData->pLda, &Iter, pPath);
	NewQuantite = strtol(new_text, NULL, 10);
	
	if(NewQuantite > 0){
		tabArticles = getTabIdArticle(pData->pLdaChainee, position);
		pPrix = getArticlePriceBySousCategory(pData->pMagasin, tabArticles[0], tabArticles[1], tabArticles[2]);
		NewPrix = strtod(pPrix, NULL)*NewQuantite;
		free(pPrix);
		pPrix = g_strdup_printf("%.2f", NewPrix);
		gtk_list_store_set(pData->pLda, &Iter, PRIX_COLUMN_LDA, pPrix, QUANTITE_COLUMN_LDA, NewQuantite, -1);
		free(pPrix);
		
		mettreNouveauQuantite(pData->pLdaChainee, position, NewQuantite);
		updateNbArtEtPrixTot(pData);
	}
	gtk_tree_path_free(pPath);
}

void OnRemove(GtkWidget *pWidget, glda *pData){
	GList *listArt;
	gint nbSelectedArt;
	gint *tabArt;
	GtkTreeIter pIter;
	gint cpt;
	gchar *sText;
	GtkTreePath *pPath;
	
	listArt = gtk_tree_selection_get_selected_rows(pData->selectLda, NULL);
	if(listArt != NULL){
		nbSelectedArt = gtk_tree_selection_count_selected_rows(pData->selectLda);
		
		cpt = 0;
		for(cpt=0;cpt<nbSelectedArt;cpt++){
			tabArt = gtk_tree_path_get_indices(g_list_nth_data(listArt, nbSelectedArt-cpt-1));
			sText = g_strdup_printf("%d", tabArt[0]);
			pPath = gtk_tree_path_new_from_string(sText);
			
			gtk_tree_model_get_iter((GtkTreeModel*)pData->pLda, &pIter, pPath);
			gtk_list_store_remove(pData->pLda, &pIter);
			
			pData->pLdaChainee = SupprArticle(pData->pLdaChainee, tabArt[0]);
			gtk_tree_path_free(pPath);
			g_free(sText);
		}
		
		updateNbArtEtPrixTot(pData);
		pData->save = FALSE;
	}
}

void OnPrint(GtkWidget *pWidget, glda *pData){
	create_pPrint(pData);
}

/*** callbacks de l'affichage des articles ***/
void ShowArticle(GtkTreeSelection *select, glda *pData){
	GList *list;
	int imb;
	int *tab = NULL;
	
	list = gtk_tree_selection_get_selected_rows(select, NULL);
	
	if(list != NULL){
		/* Niveau d'imbrication */
		imb = gtk_tree_path_get_depth(list->data);
		if(imb == 2){
			tab = gtk_tree_path_get_indices(list->data);
			create_pListArt(pData, tab[0]+1, tab[1]+1);
		}
		g_list_free(list);
		free(tab);
	}
}
