/*
	config.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gtk/gtk.h>

#include "interface.h"
#include "magasin.h"
#include "lda.h"
#include "main.h"

GKeyFile *initConfig(){
	GKeyFile* ConfigLda = NULL;
	gchar *fileUserConfig = NULL;
	gchar *fileXML = NULL;
	gchar *dirUserConfig = NULL;
	/*gchar *sText;*/
	FILE *fic = NULL;
	
	ConfigLda = g_key_file_new();
	
	fileUserConfig = g_strdup_printf("%s%s%s", getenv("HOME"), DIR_USER_CONFIG, FILE_USER_CONFIG);
	
	if(g_file_test(fileUserConfig, G_FILE_TEST_EXISTS) == FALSE){
		dirUserConfig = g_strdup_printf("%s%s", getenv("HOME"), DIR_USER_CONFIG);
		if(g_file_test(dirUserConfig, G_FILE_TEST_IS_DIR) == FALSE){
			if(g_mkdir(dirUserConfig, 0750) == -1){
				fprintf(stderr, "Impossible de créer le dossier de préférences\n");
				g_free(dirUserConfig);
				g_free(fileUserConfig);
				return NULL;
			}
		}
		/*
		A modifier
		sText = g_strdup_printf("cp /etc/glda/glda.conf.default %s", fileUserConfig);
		system(sText);
		g_free(sText);*/
		/* Génération du fichier de config */
		fic = fopen(fileUserConfig, "w");
		if(fic == NULL){
			fprintf(stderr, "Impossible de créer le fichier de config\n");
			g_free(dirUserConfig);
			g_free(fileUserConfig);
			return NULL;
		}
		
		fprintf(fic, "\
[general]\n\
lang=fr\n\
devise=euros\n\
\n\
[file]\n\
listeFile=%s/liste.xml\n\
\n\
[HTMLOption]\n\
BodyBgcolor=#ffffff\n\
BodyText=#000000\n\
TabBorder=1\n\
TabBgcolor=#ffffff\n\
TabHeadBgcolor=#c0c0c0\n\
TabCellBgcolor1=#ffffff\n\
TabCellBgcolor2=#ffffff\n\
TabCellspacing=0\n\
TabCellpadding=5\n\
TabHeadAlign=center\n\
TabCellAlign=center\n\
TabHeadValign=middle\n\
TabCellValign=middle", dirUserConfig);
		fclose(fic);
		
		fileXML = g_strdup_printf("%s/liste.xml", dirUserConfig);
		
		fic = fopen(fileXML, "w");
		if(fic == NULL){
			fprintf(stderr, "Impossible de créer le fichier de le fichier xml\n");
			g_free(fileXML);
			g_free(dirUserConfig);
			g_free(fileUserConfig);
			return NULL;
		}
		/* A developper pour fournir la liste par défaut */
		fprintf(fic, "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<liste_articles/>\n");
		fclose(fic);
		
		g_free(fileXML);
		g_free(dirUserConfig);
	}
	
	if(g_key_file_load_from_file(ConfigLda, (const gchar*)fileUserConfig, G_KEY_FILE_NONE, NULL) == FALSE){
		fprintf(stderr, "Impossible de charger le fichier de config...\n");
		g_free(fileUserConfig);
		return NULL;
	}
	
	g_free(fileUserConfig);
	return ConfigLda;
}

/*gchar *getUserLang(GKeyFile* ConfigLda){
	return g_key_file_get_string(ConfigLda, "general", "lang", NULL);
}

gchar *getUserDevise(GKeyFile* ConfigLda){
	return g_key_file_get_string(ConfigLda, "general", "devise", NULL);
}*/
void freeConfig(GKeyFile* ConfigLda){
	g_key_file_free(ConfigLda);
}
