/*
	interface.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>
#include <gtk/gtk.h>

#include "main.h"
#include "interface.h"

void create_pWindow(glda *pGlda){
        GtkWidget *pVBox;
        GtkWidget *pHBox;
        GtkWidget *pMenuBar;
        GtkWidget *pSupermarket;
        GtkWidget *pAddDellPrint;
        GtkWidget *pListDAchat;
        GtkWidget *pStatusBar;
        gchar *pText;

	/*** Creation de la fenetre principale ***/
        pGlda->pWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
        gtk_window_set_position(GTK_WINDOW(pGlda->pWindow), GTK_WIN_POS_CENTER);
        gtk_window_set_default_size(GTK_WINDOW(pGlda->pWindow), 900, 500);
        pText = g_strdup_printf("Glda v%s", pGlda->version);
        gtk_window_set_title(GTK_WINDOW(pGlda->pWindow), pText);
        gtk_window_set_icon_from_file(GTK_WINDOW(pGlda->pWindow), ICON_GLDA, NULL);
        g_signal_connect(G_OBJECT(pGlda->pWindow), "destroy", G_CALLBACK(OnDestroy), (glda*)pGlda);
        g_signal_connect(G_OBJECT(pGlda->pWindow), "delete-event", G_CALLBACK(OnQuit), (glda*)pGlda);

        /* Creation de GtkBox vertical */
        pVBox = gtk_vbox_new(FALSE, 0);
        gtk_container_add(GTK_CONTAINER(pGlda->pWindow), pVBox);

        /*** Creation du menu ***/
        pMenuBar = create_pMenuBar(pGlda);
        /* Insertion de la barre de menu dans le pVBox */
        gtk_box_pack_start(GTK_BOX(pVBox), pMenuBar, FALSE, FALSE, 0);

	/* Creation GtkBox horizontal */
        pHBox = gtk_hbox_new(FALSE, 0);
        gtk_box_pack_start(GTK_BOX(pVBox), pHBox, TRUE, TRUE, 0);

	/*** Corps de l'appli ***/
        /** Creation de la liste de Supermarché **/
        pSupermarket = create_pListSuperMarket(pGlda);
        gtk_box_pack_start(GTK_BOX(pHBox), pSupermarket, TRUE, TRUE, 0);

	/** Creation de boutons ajout/suppr/imprimer **/
	pAddDellPrint = create_pAddDellPrint(pGlda);
        gtk_box_pack_start(GTK_BOX(pHBox), pAddDellPrint, FALSE, FALSE, 10);

	/** Creation de la liste d'achat **/
	pListDAchat = create_pListDAchat(pGlda);
	gtk_box_pack_start(GTK_BOX(pHBox), pListDAchat, TRUE, TRUE, 0);
	
	/*** Creation de la barre d'etat ***/
	pStatusBar = gtk_statusbar_new();
	gtk_box_pack_start(GTK_BOX(pVBox), pStatusBar, FALSE, FALSE, 0);
	gtk_statusbar_push(GTK_STATUSBAR(pStatusBar), GPOINTER_TO_INT(0), pText);
	
	g_free(pText);
}

GtkWidget* create_pMenuBar(glda *pGlda){
	GtkWidget *pMenuBar;
        GtkWidget *pMenu;
        GtkAccelGroup *pAccel;
        GtkWidget *pMenuItem;

        /*** Barre de menu ***/
        pMenuBar = gtk_menu_bar_new();

        /** Menu "Fichier" **/
        pMenu = gtk_menu_new();
        pAccel = gtk_accel_group_new();

        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_NEW, pAccel);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
	g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnNew), (GtkWidget*) pGlda);

        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_OPEN, pAccel);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
	g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnOpen), (GtkWidget*) pGlda);

        pMenuItem = gtk_separator_menu_item_new();
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        
        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_SAVE, pAccel);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnSave), (glda*)pGlda);

        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_SAVE_AS, NULL);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnSaveAs), (glda*)pGlda);
        
        pMenuItem = gtk_image_menu_item_new_with_label("Exporter");
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnExport), (glda*)pGlda);
        
        pMenuItem = gtk_separator_menu_item_new();
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        
        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_PRINT, pAccel);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnPrint), (glda*)pGlda);
        
        pMenuItem = gtk_separator_menu_item_new();
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        
        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_QUIT, pAccel);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnDestroy), (glda*)pGlda);

        pMenuItem = gtk_menu_item_new_with_label("Fichier");
        gtk_menu_item_set_submenu(GTK_MENU_ITEM(pMenuItem), pMenu);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenuBar), pMenuItem);
        
        /* Association des raccourcis avec la fenetre */
	gtk_window_add_accel_group(GTK_WINDOW(pGlda->pWindow), pAccel);

        /** Menu Edition **/
        pMenu = gtk_menu_new();
        
        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_ADD, NULL);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnAdd), (glda*) pGlda);
        
        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_REMOVE, NULL);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnRemove), (glda*) pGlda);
        
        pMenuItem = gtk_separator_menu_item_new();
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        
        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_PREFERENCES, NULL);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnPreferences), (glda*) pGlda);
        
        pMenuItem = gtk_menu_item_new_with_label("Edition");
        gtk_menu_item_set_submenu(GTK_MENU_ITEM(pMenuItem), pMenu);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenuBar), pMenuItem);
        
        /** Menu aide ou "?" **/
        pMenu = gtk_menu_new();

        pMenuItem = gtk_image_menu_item_new_from_stock(GTK_STOCK_ABOUT, NULL);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenu), pMenuItem);
        g_signal_connect(G_OBJECT(pMenuItem), "activate", G_CALLBACK(OnAbout), (glda*) pGlda);

        pMenuItem = gtk_menu_item_new_with_label("?");
        gtk_menu_item_set_submenu(GTK_MENU_ITEM(pMenuItem), pMenu);
        gtk_menu_shell_append(GTK_MENU_SHELL(pMenuBar), pMenuItem);

	return pMenuBar;
}

GtkWidget* create_pListSuperMarket(glda *pGlda){
	GtkWidget *hpaned;
	GtkWidget *pVBox;
	GtkWidget *pScrollbar;
	GtkWidget *pTreeView;
	GtkTreeViewColumn *pColumn;
        GtkCellRenderer *pCellRenderer;
        gchar *pText;
	
	/* */
	hpaned = gtk_hpaned_new();

	/* Partie Magasins */	
	pVBox = gtk_vbox_new(TRUE, 0);
        /* gtk_paned_add1(GTK_PANED(hpaned), pVBox);*/
        gtk_paned_pack1(GTK_PANED (hpaned), pVBox, TRUE, FALSE);
        pScrollbar = gtk_scrolled_window_new(NULL, NULL);
        gtk_box_pack_start(GTK_BOX(pVBox), pScrollbar, TRUE, TRUE, 0);
	
	/* Creation du modele */
	pGlda->pListCat = gtk_tree_store_new(N_COLUMN_MAGASINS, G_TYPE_STRING);
	
	create_pListCat(pGlda);
	
	/* Creation de la vue */
	pTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pGlda->pListCat));
	
	/* Possibilité de recherche en fonction du nom de la catégorie et sous catégorie */
	gtk_tree_view_set_search_column(GTK_TREE_VIEW(pTreeView), MAGASINS_COLUMN);
	
	/* Donner la possibilité de simple selection */
	pGlda->selectCat = gtk_tree_view_get_selection(GTK_TREE_VIEW(pTreeView));
	gtk_tree_selection_set_mode(pGlda->selectCat, GTK_SELECTION_SINGLE);
	g_signal_connect(G_OBJECT(pGlda->selectCat), "changed", G_CALLBACK(ShowArticle), pGlda);
	
	/* Creation de la colonne */
	pCellRenderer = gtk_cell_renderer_text_new();
	pColumn = gtk_tree_view_column_new_with_attributes("Magasin", pCellRenderer, "text", 0, NULL);
	gtk_tree_view_append_column(GTK_TREE_VIEW(pTreeView), pColumn);
	
        gtk_container_add(GTK_CONTAINER(pScrollbar), pTreeView);
	
	/* Partie Articles */
        pVBox = gtk_vbox_new(TRUE, 0);
        /* gtk_paned_add2(GTK_PANED(hpaned), pVBox); */
        gtk_paned_pack2(GTK_PANED (hpaned), pVBox, TRUE, FALSE);
        pScrollbar = gtk_scrolled_window_new(NULL, NULL);
        gtk_box_pack_start(GTK_BOX(pVBox), pScrollbar, TRUE, TRUE, 0);
        
	/* Creation du modele */
	pGlda->pListArt = gtk_list_store_new(N_COLUMN_PRODUITS, G_TYPE_STRING, G_TYPE_STRING);
	
        /* create_pListArt(pGlda); */
        
        /* Creation de la vue */
	pTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pGlda->pListArt));
	
	/* Possibilité de recherche en fonction du nom de l'article */
	gtk_tree_view_set_search_column(GTK_TREE_VIEW(pTreeView), PRODUITS_COLUMN);
	
	/* Donner la possibilité de selection multiple */
	pGlda->selectArt = gtk_tree_view_get_selection(GTK_TREE_VIEW(pTreeView));
	gtk_tree_selection_set_mode(pGlda->selectArt, GTK_SELECTION_MULTIPLE);
	
	/* Creation des colonnes */
	/* colonnes "Produits" */
	pCellRenderer = gtk_cell_renderer_text_new();
	pColumn = gtk_tree_view_column_new_with_attributes("Produits", pCellRenderer, "text", PRODUITS_COLUMN, NULL);
	gtk_tree_view_column_set_resizable(pColumn, TRUE);
	gtk_tree_view_column_set_min_width(pColumn, 100);
	gtk_tree_view_append_column(GTK_TREE_VIEW(pTreeView), pColumn);
	
	/* colonnes "Prix" */
	pText = g_strdup_printf("Prix (en %s)", g_key_file_get_string(pGlda->pConfig, "general", "devise", NULL));
	pCellRenderer = gtk_cell_renderer_text_new();
	pColumn = gtk_tree_view_column_new_with_attributes(pText, pCellRenderer, "text", PRIX_COLUMN, NULL);
	gtk_tree_view_column_set_resizable(pColumn, TRUE);
	gtk_tree_view_column_set_min_width(pColumn, 50);
	gtk_tree_view_append_column(GTK_TREE_VIEW(pTreeView), pColumn);
	g_free(pText);
	
        gtk_container_add(GTK_CONTAINER(pScrollbar), pTreeView);
        
        return hpaned;
}

void create_pListCat(glda *pGlda){
	GtkTreeIter pIter;
        GtkTreeIter pIter2;
        gchar *ptrCategory = NULL;
        gchar *ptrSSCategory = NULL;
        int cpt1, cpt2;
	
	/* Insertion des elements */
	cpt1 = 1;
	do{
	        ptrCategory = getCategoryById(pGlda->pMagasin, cpt1);
		if(strcmp(ptrCategory, "FIN") != 0){
	        	/* Creation de la nouvelle ligne */
        		gtk_tree_store_append(pGlda->pListCat, &pIter, NULL);
        		/* Mise a jour des donnees */
        		gtk_tree_store_set(pGlda->pListCat, &pIter, MAGASINS_COLUMN, ptrCategory, -1);
        		
        		cpt2 = 1;
			do{
        			ptrSSCategory = getSousCategoryByCategory(pGlda->pMagasin, cpt1, cpt2);
				if(strcmp(ptrSSCategory, "FIN") != 0){
        				/* Creation de la nouvelle ligne enfant */
        				gtk_tree_store_append(pGlda->pListCat, &pIter2, &pIter);
        				
        				/* Mise a jour des donnees */
        				gtk_tree_store_set(pGlda->pListCat, &pIter2, MAGASINS_COLUMN, ptrSSCategory, -1);
			}
				cpt2++;
			}while(strcmp(ptrSSCategory, "FIN") != 0);
		}	
		cpt1++;
	}while(strcmp(ptrCategory, "FIN") != 0);
	
	free(ptrCategory);
	free(ptrSSCategory);
}

void create_pListArt(glda *pGlda, int IdCat, int IdSSCat){
	GtkTreeIter pIter;
	char *ptrArticleName = NULL;
	char *ptrArticlePrice = NULL;
	int cpt1;
	
	gtk_list_store_clear(pGlda->pListArt);
        
        /* Insertion des elements */
        cpt1 = 1;
        do{
        	ptrArticleName = getArticleNameBySousCategory(pGlda->pMagasin, IdCat, IdSSCat, cpt1);
		if(strcmp(ptrArticleName, "FIN") != 0){
			ptrArticlePrice = getArticlePriceBySousCategory(pGlda->pMagasin, IdCat, IdSSCat, cpt1);
			/* Creation de la nouvelle ligne */
			gtk_list_store_append(pGlda->pListArt, &pIter);
			
			/* Mise a jour des donnees */
		        gtk_list_store_set(pGlda->pListArt, &pIter, PRODUITS_COLUMN, ptrArticleName, PRIX_COLUMN, ptrArticlePrice, -1);
		}
		cpt1++;
	}while(strcmp(ptrArticleName, "FIN") != 0);
	free(ptrArticleName);
	free(ptrArticlePrice);
}

GtkWidget* create_pAddDellPrint(glda *pGlda){
	GtkWidget *pVBox;
	GtkWidget *pButton;
	
	pVBox = gtk_vbox_new(TRUE, 0);
	pButton = gtk_button_new_from_stock(GTK_STOCK_ADD);
        gtk_box_pack_start(GTK_BOX(pVBox), pButton, FALSE, FALSE, 0);
        g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnAdd), pGlda);
        
        pButton = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
        gtk_box_pack_start(GTK_BOX(pVBox), pButton, FALSE, FALSE, 0);
        g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnRemove), pGlda);
        
        pButton = gtk_button_new_from_stock(GTK_STOCK_PRINT);
        gtk_box_pack_start(GTK_BOX(pVBox), pButton, FALSE, FALSE, 0);
        g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnPrint), pGlda);
        
        return pVBox;
}

GtkWidget* create_pListDAchat(glda *pGlda){
	GtkWidget *pVBox;
	GtkWidget *pTable;
	GtkWidget *pScrollbar;
	GtkWidget *pListView;
	GtkTreeViewColumn *pColumn;
        GtkCellRenderer *pCellRenderer;
	GtkWidget *pLabel;
	GtkAdjustment *adj;
	gchar *sText;
        
	pVBox = gtk_vbox_new(FALSE, 0);
	
	pLabel = gtk_label_new("Liste des courses à faire");
	gtk_box_pack_start(GTK_BOX(pVBox), pLabel, FALSE, TRUE, 10);
	
        /* Creation d'un scrollbar */
        pScrollbar = gtk_scrolled_window_new(NULL, NULL);
        gtk_box_pack_start(GTK_BOX(pVBox), pScrollbar, TRUE, TRUE, 0);

        /* Creation de la liste d'achat */
        pGlda->pLda = gtk_list_store_new(N_COLUMN_LDA, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT);
	
        /* Creation de la vue */
        pListView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pGlda->pLda));
	
	/* Possibilité de recherche en fonction du nom de l'article */
	gtk_tree_view_set_search_column(GTK_TREE_VIEW(pListView), PRODUITS_COLUMN_LDA);
	
	/* Donner la possibilité de selection multiple */
	pGlda->selectLda = gtk_tree_view_get_selection(GTK_TREE_VIEW(pListView));
	gtk_tree_selection_set_mode(pGlda->selectLda, GTK_SELECTION_MULTIPLE);
	
	/* Creation des colonnes */
	pCellRenderer = gtk_cell_renderer_text_new();
        pColumn = gtk_tree_view_column_new_with_attributes("Produits", pCellRenderer, "text", PRODUITS_COLUMN_LDA, NULL);
        gtk_tree_view_column_set_resizable(pColumn, TRUE);
        gtk_tree_view_column_set_min_width(pColumn, 200);
        gtk_tree_view_append_column(GTK_TREE_VIEW(pListView), pColumn);
        
        pCellRenderer = gtk_cell_renderer_text_new();
        pColumn = gtk_tree_view_column_new_with_attributes("Prix", pCellRenderer, "text", PRIX_COLUMN_LDA, NULL);
        gtk_tree_view_column_set_resizable(pColumn, TRUE);
        gtk_tree_view_column_set_min_width(pColumn, 100);
        gtk_tree_view_append_column(GTK_TREE_VIEW(pListView), pColumn);

	/* Permet l'edition de la colonne Quantite */
        /* Incopatible avec les versions antérieures à 2.10 de Gtk+ */
        adj = GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 1.0, 2.0, 2.0));
        pCellRenderer = gtk_cell_renderer_spin_new();
        g_object_set(pCellRenderer, "editable", TRUE, "adjustment", adj, "digits", 0, NULL);
        pColumn = gtk_tree_view_column_new_with_attributes("Quantité", pCellRenderer, "text", QUANTITE_COLUMN_LDA, NULL);
        gtk_tree_view_column_set_resizable(pColumn, TRUE);
        gtk_tree_view_column_set_min_width(pColumn, 50);
        g_signal_connect(G_OBJECT(pCellRenderer), "edited", G_CALLBACK(cell_edited), (glda*)pGlda);
        gtk_tree_view_append_column(GTK_TREE_VIEW(pListView), pColumn);
        
        /* Pour la compatibilité avec Gtk 2.10 et antérieures */
        /*pCellRenderer = gtk_cell_renderer_text_new();
        pColumn = gtk_tree_view_column_new_with_attributes("Quantité", pCellRenderer, "text", QUANTITE_COLUMN_LDA, NULL);
        gtk_tree_view_column_set_resizable(pColumn, TRUE);
        gtk_tree_view_append_column(GTK_TREE_VIEW(pListView), pColumn);*/

        gtk_container_add(GTK_CONTAINER(pScrollbar), pListView);

	/* Creation de l'affichage de Total */
	pTable = gtk_table_new(2, 2, FALSE);
	
	gtk_box_pack_start(GTK_BOX(pVBox), pTable, FALSE, FALSE, 10);
	
	pLabel = gtk_label_new("Nombre d'article(s) : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 0, 1);
	
	pGlda->pLabelNbArt = gtk_label_new("0");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pGlda->pLabelNbArt, 1, 2, 0, 1);
	
	pLabel = gtk_label_new("Total : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 1, 2);
	
	sText = g_strdup_printf("0 %s", g_key_file_get_string(pGlda->pConfig, "general", "devise", NULL));
	pGlda->pLabelPrixTot = gtk_label_new(sText);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pGlda->pLabelPrixTot, 1, 2, 1, 2);
	g_free(sText);
	return pVBox;
}

void addArt(glda *pGlda, int IdCat, int IdSSCat, int IdArt, int Quantite){
	GtkTreeIter pIter;
	char *ptrArticleName, *ptrArticlePrice;
	
	ptrArticleName = getArticleNameBySousCategory(pGlda->pMagasin, IdCat, IdSSCat, IdArt);
	ptrArticlePrice = getArticlePriceBySousCategory(pGlda->pMagasin, IdCat, IdSSCat, IdArt);
	
	/* Creation de la nouvelle ligne */
        gtk_list_store_append(pGlda->pLda, &pIter);
        gtk_list_store_set(pGlda->pLda, &pIter, PRODUITS_COLUMN_LDA, ptrArticleName, PRIX_COLUMN_LDA, ptrArticlePrice, QUANTITE_COLUMN_LDA, Quantite, -1);
        
        free(ptrArticleName);
	free(ptrArticlePrice);
}

void openLDA(glda *pGlda){
        Lda *pLdaCourant;
	Article *pArticle;
        gint i;
        
        if(pGlda->pLdaChainee != NULL){
        	pLdaCourant = (Lda*)g_slist_nth((GSList*)pGlda->pLdaChainee, 0);
		pArticle = g_slist_nth_data((GSList*)pGlda->pLdaChainee, 0);
		i = 1;
		while(pLdaCourant != NULL){
			addArt(pGlda, pArticle->TabIdArticle[0], pArticle->TabIdArticle[1], pArticle->TabIdArticle[2], pArticle->Quantite);
			
			pLdaCourant = (Lda*)g_slist_nth((GSList*)pGlda->pLdaChainee, i);
			pArticle = g_slist_nth_data((GSList*)pGlda->pLdaChainee, i);
			i++;
		}
		updateNbArtEtPrixTot(pGlda);
	}
	else{
		errorDialog(pGlda, "Fichier Lda incorrect. :(");
		pGlda->fichierLDA = NULL;
	}
}

void updateNbArtEtPrixTot(glda *pGlda){
	gchar *sText;
	gint NbArt;
	gdouble PrixTot;
	
        /* Mis a jour du nb articles et prix total */
        getNbArticlesAndPrixTotal(pGlda->pLdaChainee, pGlda->pMagasin, &NbArt, &PrixTot);
        sText = g_strdup_printf("%d", NbArt);
        gtk_label_set_label(GTK_LABEL(pGlda->pLabelNbArt), sText);
        g_free(sText);
        
        sText = g_strdup_printf("%.2f %s", PrixTot, g_key_file_get_string(pGlda->pConfig, "general", "devise", NULL));
        gtk_label_set_label(GTK_LABEL(pGlda->pLabelPrixTot), sText);
        g_free(sText);
}

void openList(glda *pGlda){
	GtkWidget *pFileSelection;
	
	/* Creation de la fenetre de selection */
	pFileSelection = gtk_file_chooser_dialog_new("Enregistrer sous...",
							GTK_WINDOW(pGlda->pWindow),
							GTK_FILE_CHOOSER_ACTION_OPEN,
							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
							GTK_STOCK_OPEN, GTK_RESPONSE_OK,
							NULL);
	
	/* Affichage fenetre */
	switch(gtk_dialog_run(GTK_DIALOG(pFileSelection))){
		case GTK_RESPONSE_OK:
			/* Recuperation du chemin */
			pGlda->fichierLDA = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(pFileSelection));
			if(g_file_test(pGlda->fichierLDA, G_FILE_TEST_EXISTS) == TRUE){
				pGlda->pLdaChainee = openListeLDA(pGlda->pLdaChainee, pGlda->pMagasin, pGlda->fichierLDA, pGlda->pConfig);
				openLDA(pGlda);
			}
			else{
				errorDialog(pGlda, "Fichier Lda inexistant. :(");
			}
			break;
		default:
			break;
	}
	gtk_widget_destroy(pFileSelection);
}

void saveList(glda *pGlda){
	GtkWidget *pFileSelection;
	
	if(pGlda->fichierLDA != NULL){
		saveListeDefault(pGlda->pLdaChainee, pGlda->pMagasin, pGlda->fichierLDA, pGlda->pConfig);
		pGlda->save = TRUE;
	}
	else{
		/* Creation de la fenetre de selection */
		pFileSelection = gtk_file_chooser_dialog_new("Enregistrer sous...",
								GTK_WINDOW(pGlda->pWindow),
								GTK_FILE_CHOOSER_ACTION_SAVE,
								GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
								GTK_STOCK_SAVE, GTK_RESPONSE_OK,
								NULL);
		
		/* Affichage fenetre */
		switch(gtk_dialog_run(GTK_DIALOG(pFileSelection))){
			case GTK_RESPONSE_OK:
				/* Recuperation du chemin */
				pGlda->fichierLDA = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(pFileSelection));
				if(g_file_test(pGlda->fichierLDA, G_FILE_TEST_EXISTS) == TRUE){
					if(yesOrNoDialog(pGlda, "Ce fichier existe déjà. Voulez-vous le remplacer ?") == TRUE){
						saveListeDefault(pGlda->pLdaChainee, pGlda->pMagasin, pGlda->fichierLDA, pGlda->pConfig);
						pGlda->save = TRUE;
					}
					else{
						pGlda->fichierLDA = NULL;
					}
				}
				else{
					saveListeDefault(pGlda->pLdaChainee, pGlda->pMagasin, pGlda->fichierLDA, pGlda->pConfig);
				}
				break;
			default:
				break;
		}
		gtk_widget_destroy(pFileSelection);
	}
}

void saveListAs(glda *pGlda){
	GtkWidget *pFileSelection;
	
	pFileSelection = gtk_file_chooser_dialog_new("Enregistrer sous...",
							GTK_WINDOW(pGlda->pWindow),
							GTK_FILE_CHOOSER_ACTION_SAVE,
							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
							GTK_STOCK_SAVE, GTK_RESPONSE_OK,
							NULL);
	
	/* Affichage fenetre */
	switch(gtk_dialog_run(GTK_DIALOG(pFileSelection))){
		case GTK_RESPONSE_OK:
			/* Recuperation du chemin */
			pGlda->fichierLDA = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(pFileSelection));
			if(g_file_test(pGlda->fichierLDA, G_FILE_TEST_EXISTS) == TRUE){
				if(yesOrNoDialog(pGlda, "Ce fichier existe déjà. Voulez-vous le remplacer ?") == TRUE){
					saveListeDefault(pGlda->pLdaChainee, pGlda->pMagasin, pGlda->fichierLDA, pGlda->pConfig);
					pGlda->save = TRUE;
				}
				else{
					pGlda->fichierLDA = NULL;
				}
			}
			else{
				saveListeDefault(pGlda->pLdaChainee, pGlda->pMagasin, pGlda->fichierLDA, pGlda->pConfig);
			}
			break;
		default:
			break;
	}
	gtk_widget_destroy(pFileSelection);
}

void exportList(glda *pGlda){
	GtkWidget *pFileSelection;
	gchar *fichierTXT;
	
	pFileSelection = gtk_file_chooser_dialog_new("Exporter...",
							GTK_WINDOW(pGlda->pWindow),
							GTK_FILE_CHOOSER_ACTION_SAVE,
							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
							GTK_STOCK_SAVE, GTK_RESPONSE_OK,
							NULL);
	
	/* Affichage fenetre */
	switch(gtk_dialog_run(GTK_DIALOG(pFileSelection))){
		case GTK_RESPONSE_OK:
			/* Recuperation du chemin */
			fichierTXT = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(pFileSelection));
			if(g_file_test(fichierTXT, G_FILE_TEST_EXISTS) == TRUE){
				if(yesOrNoDialog(pGlda, "Ce fichier existe déjà. Voulez-vous le remplacer ?") == TRUE){
					saveListToTxt(pGlda->pLdaChainee, pGlda->pMagasin, fichierTXT, pGlda->pConfig);
				}
			}
			else{
				saveListToTxt(pGlda->pLdaChainee, pGlda->pMagasin, fichierTXT, pGlda->pConfig);
			}
			g_free(fichierTXT);
			break;
		default:
			break;
	}
	gtk_widget_destroy(pFileSelection);
}

gboolean yesOrNoDialog(glda *pGlda, gchar *msg){
	GtkWidget *pQuestion;
	
	pQuestion = gtk_message_dialog_new(GTK_WINDOW(pGlda->pWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, msg);
	
	switch(gtk_dialog_run(GTK_DIALOG(pQuestion))){
		case GTK_RESPONSE_YES:
			gtk_widget_destroy(pQuestion);
			return TRUE;
			break;
		case GTK_RESPONSE_NO:
			gtk_widget_destroy(pQuestion);
			return FALSE;
			break;
		default:
			gtk_widget_destroy(pQuestion);
			return FALSE;
			break;
	}
}

void errorDialog(glda *pGlda, gchar *msg){
	GtkWidget *pError;
	
	pError = gtk_message_dialog_new(GTK_WINDOW(pGlda->pWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, msg);
	
	gtk_dialog_run(GTK_DIALOG(pError));
	
	gtk_widget_destroy(pError);
}

gboolean saveModif(glda *pGlda){
	GtkWidget *pDialog;
	GtkWidget *pLabel;
	
	if(pGlda->save == FALSE){
		pDialog = gtk_dialog_new_with_buttons("Quitter Glda",
							GTK_WINDOW(pGlda->pWindow),
							GTK_DIALOG_MODAL,
							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
							GTK_STOCK_NO, GTK_RESPONSE_NO,
							GTK_STOCK_YES, GTK_RESPONSE_YES,
							NULL);
		pLabel = gtk_label_new("Voulez-vous enregistrer les modifications ?");
		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(pDialog)->vbox), pLabel, TRUE, FALSE, 0);
		
		/* Affichage des elements de la boite de dialogue */
		gtk_widget_show_all(GTK_DIALOG(pDialog)->vbox);
		
		/* On lance la boite de dialogue et on recupere la reponse */
		switch(gtk_dialog_run(GTK_DIALOG(pDialog))){
			case GTK_RESPONSE_YES:
				gtk_widget_destroy(pDialog);
				saveList(pGlda);
				return TRUE;
				break;
			case GTK_RESPONSE_NO:
				gtk_widget_destroy(pDialog);
				return TRUE;
				break;
			case GTK_RESPONSE_CANCEL:
				gtk_widget_destroy(pDialog);
				return FALSE;
				break;
			default:
				gtk_widget_destroy(pDialog);
				return FALSE;
				break;
		}
	}
	else{
		return TRUE;
	}
}

void create_pAbout(glda *pGlda){
	/*GtkWidget *pAbout;
	gchar *pText;
	pText = (gchar*)malloc(sizeof(gchar)*100);
	sprintf(pText, "Glda v%s\nGnome Liste D'Achat\nPar Tuxgasy <tuxgasy@tuxfamily.org>", pGlda->version);
        pAbout = gtk_message_dialog_new(GTK_WINDOW(pGlda->pWindow),
					GTK_DIALOG_MODAL,
					GTK_MESSAGE_INFO,
					GTK_BUTTONS_CLOSE,
					pText);

        gtk_dialog_run(GTK_DIALOG(pAbout));
        gtk_widget_destroy(pAbout);*/
        
        GtkWidget *pAbout;
        GdkPixbuf *logo;
        /*GError *error = NULL;*/
        
        const gchar *authors[] = {
        	"Tuxgasy <tuxgasy@tuxfamily.org>",
        	NULL
        };
        
        const gchar *documenters[] = {
        	"fanfan la tulipe <olivier.fandard1@tele2.fr>",
        	NULL
        };
        
        const gchar *artists[] = {
        	"Isabelle Stévant <isabelle.stevant@gmail.com>",
        	NULL
        };
        
        pAbout = gtk_about_dialog_new();
        
        logo = gdk_pixbuf_new_from_file(ICON_GLDA, NULL);
        
        gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(pAbout), logo);
        
        gtk_window_set_icon_from_file(GTK_WINDOW(pAbout), ICON_GLDA, NULL);
        
        gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(pAbout), "À propos de Glda");
        gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(pAbout), pGlda->version);
        gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(pAbout), "(c) 2008 Tuxgasy");
        gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(pAbout), "Glda (Gtk Liste D'Acahat) est un utilitaire pour faire sa liste d'achat.");
        
        gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(pAbout),
"\
Glda is free software; you can redistribute it\n\
and/or modify it under the terms of the GNU General\n\
Public License as published by the Free Software\n\
Foundation; either version 2 of the License, or (at your\n\
option) any later version.\n\
\n\
Glda is distributed in the hope that it will be\n\
useful, but WITHOUT ANY WARRANTY; without even\n\
the implied warranty of MERCHANTABILITY or\n\
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n\
General Public License for more details.\n\
\n\
You should have received a copy of the GNU General\n\
Public License along with GNOME Terminal; if not, write\n\
to the Free Software Foundation, Inc., 51 Franklin St,\n\
Fifth Floor, Boston, MA  02110-1301 USA\
	");
        gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(pAbout), "http://glda.tuxfamily.org");
        
        gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(pAbout), authors);
        gtk_about_dialog_set_documenters(GTK_ABOUT_DIALOG(pAbout), documenters);
        gtk_about_dialog_set_artists(GTK_ABOUT_DIALOG(pAbout), artists);
        
        gtk_dialog_run(GTK_DIALOG(pAbout));
        gtk_widget_destroy(pAbout);
}
