/*
	interface.h
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef DEF_INTERFACE
#define DEF_INTERFACE

#define ICON_GLDA "/usr/share/pixmaps/glda.png"

#define HEADER_HEIGHT 20.0
#define HEADER_GAP 8.5

#include <gtk/gtk.h>

#include "main.h"
#include "interface.h"

enum {MAGASINS_COLUMN, N_COLUMN_MAGASINS};
enum {PRODUITS_COLUMN, PRIX_COLUMN, N_COLUMN_PRODUITS};
enum {PRODUITS_COLUMN_LDA, PRIX_COLUMN_LDA, QUANTITE_COLUMN_LDA, N_COLUMN_LDA};

typedef struct Preferences Preferences;

struct Preferences{
	glda *pGlda;
	
	GtkWidget *pEntryListe;
	
	gboolean configModif;
	gboolean listeModif;
	
	GtkWidget *pEntryCat;
	GtkWidget *pEntrySSCat;
	GtkWidget *pEntryArtName;
	GtkWidget *pEntryArtPrice;
	GtkWidget *pComboBoxCat1;
	GtkWidget *pComboBoxCat2;
	GtkWidget *pComboBoxSSCat;
	
	GtkTreeStore *pTreeStore;
	GtkTreeSelection *selectMagasin;
};

typedef struct Print Print;

struct Print{
	glda *pGlda;
	
	gchar *filename;
	gchar **lines;
	gdouble font_size;
	gint lines_per_page;
	gint total_lines;
	gint total_pages;
};

/**************************************************************

	En-tete de "interface.c"

**************************************************************/

void create_pWindow(glda *pGlda);

GtkWidget* create_pMenuBar(glda *pGlda);

GtkWidget* create_pListSuperMarket(glda *pGlda);

void create_pListCat(glda *pGlda);

void create_pListArt(glda *pGlda, int IdCat, int IdSSCat);

GtkWidget* create_pAddDellPrint(glda *pGlda);

GtkWidget* create_pListDAchat(glda *pGlda);

void addArt(glda *pGlda, int IdCat, int IdSSCat, int IdArt, int Quantite);

void openLDA(glda *pGlda);

void updateNbArtEtPrixTot(glda *pGlda);

void openList(glda *pGlda);

void saveList(glda *pGlda);
void saveListAs(glda *pGlda);
void exportList(glda *pGlda);

gboolean yesOrNoDialog(glda *pGlda, gchar *msg);
void errorDialog(glda *pGlda, gchar *msg);

gboolean saveModif(glda *pGlda);

void create_pAbout(glda *pGlda);

/***************************************************************

	En-tete de "callbacks.c"

****************************************************************/

void OnNew(GtkWidget *pWidget, glda *pData);

void OnOpen(GtkWidget *pWidget, glda *pData);

void OnSave(GtkWidget *pWidget, glda *pData);
void OnSaveAs(GtkWidget *pWidget, glda *pData);
void OnExport(GtkWidget *pWidget, glda *pData);

void OnPreferences(GtkWidget *pWidget, glda *pData);

void ShowArticle(GtkTreeSelection *select, glda *pData);

void OnAdd(GtkWidget *pWidget, glda *pData);

void cell_edited(GtkCellRendererText *renderer, gchar *path, gchar *new_text, glda *pData);

void OnRemove(GtkWidget *pWidget, glda *pData);

void OnPrint(GtkWidget *pWidget, glda *pData);

void OnAbout(GtkWidget *pWidget, glda *pData);

void OnDestroy(GtkWidget *pWidget, glda *pData);

gboolean OnQuit(GtkWidget *pWindow, GdkEvent *pEvent, glda *pData);

/***************************************************************

	En-tete de preferencesInterface.c

***************************************************************/

void create_pPreferences(glda *pGlda);

GtkWidget *create_pGeneral(Preferences *pPreferencesData);

GtkWidget *create_pModifListe(Preferences *pPreferencesData);

GtkWidget *create_pEdition(Preferences *pPreferencesData);

GtkTreeStore *create_pListeCatEdition(Preferences *pPreferencesData);

GtkWidget *create_pListeDeroulanteCat(Preferences *pPreferencesData);

GtkWidget *create_pListeDeroulanteSSCat(Preferences *pPreferencesData, gint idCat);

void change_pListeDeroulanteSSCat(Preferences *pPreferencesData, gint idCat);

void addCategoryToInterface(Preferences *pPreferencesData, gchar *Name);

void addSSCategoryToInterface(Preferences *pPreferencesData, gint idCat, gchar *Name);

void addArticleToInterface(Preferences *pPreferencesData, gint idCat, gint idSSCat, gchar *Name, gchar *Prix);

void removeCategoryToInterface(Preferences *pPreferencesData, gint idCat);

void removeSSCategoryToInterface(Preferences *pPreferencesData, gint idCat, gint idSSCat);

void removeArticleToInterface(Preferences *pPreferencesData, gint idCat, gint idSSCat, gint idArt);

void editCategory(Preferences *pPreferencesData, gint idCat);

void editSSCategory(Preferences *pPreferencesData, gint idCat, gint idSSCat);

void editArticle(Preferences *pPreferencesData, gint idCat, gint idSSCat, gint idArt);

void modifyCategoryToInterface(Preferences *pPreferencesData, gchar *Name, gint idCat);

void modifySSCategoryToInterface(Preferences *pPreferencesData, gchar *Name, gint idCat, gint idSSCat);

void modifyArticleToInterface(Preferences *pPreferencesData, gchar *Name, gchar *Prix, gint idCat, gint idSSCat, gint idArt);

void modifyFileXml(Preferences *pPreferencesData);

/***************************************************************

	En-tete de preferencesCallbacks.c

***************************************************************/

void OnChangedLangue(GtkWidget *pEntry, Preferences *pPreferencesData);

void OnChangedDevise(GtkWidget *pEntry, Preferences *pPreferencesData);

void OnChangedListe(GtkWidget *pEntry, Preferences *pPreferencesData);

void OnOpenListe(GtkWidget *pButton, Preferences *pPreferencesData);

void OnClearCat(GtkWidget *pButton, Preferences *pPreferencesData);

void OnClearSSCat(GtkWidget *pButton, Preferences *pPreferencesData);

void OnClearArt(GtkWidget *pButton, Preferences *pPreferencesData);

void OnAddCat(GtkWidget *pButton, Preferences *pPreferencesData);

void OnAddSSCat(GtkWidget *pButton, Preferences *pPreferencesData);

void OnAddArt(GtkWidget *pButton, Preferences *pPreferencesData);

void OnChangeListeCategory(GtkWidget *pComboBox, Preferences *pPreferencesData);

void OnRemoveToMagasin(GtkWidget *pButton, Preferences *pPreferencesData);

void OnEditList(GtkWidget *pButton, Preferences *pPreferencesData);

/****************************************************************

	En-tete de printInterface.c

****************************************************************/

void create_pPrint(glda *pGlda);

/***************************************************************

	En-tete de printCallbacks.c

***************************************************************/

void begin_print(GtkPrintOperation *operation, GtkPrintContext *context, Print *pPrintData);

void draw_page(GtkPrintOperation *operation, GtkPrintContext *context, gint page_nr, Print *pPrintData);

void end_print(GtkPrintOperation *operation, GtkPrintContext *context, Print *pPrintData);

#endif
