/*
	magasin.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>

#include "main.h"
#include "magasin.h"
#include "lda.h"

Magasin initMagasin(const gchar *fichierXML){
	Magasin pMagasin;
	xmlNodePtr racine;
	
	/* Vérification du fichier passé en argument */
	if(g_file_test(fichierXML, G_FILE_TEST_EXISTS) == FALSE){
		fprintf(stderr, "Impossible de trouver le fichier:\n%s\n", fichierXML);
		return NULL;
	}
	
	/* Ouverture du fichier XML */
	pMagasin = (Magasin)xmlParseFile(fichierXML);
	if(pMagasin == NULL){
		fprintf(stderr, "Fichier XML invalide:\n%s\n", fichierXML);
		return NULL;
	}

	/* Lecture */
	racine = xmlDocGetRootElement((xmlDocPtr)pMagasin);
	if(racine == NULL){
		fprintf(stderr, "Fichier XML vide\n");
		return NULL;
	}
	
	return pMagasin;
}

void show(xmlNodePtr node){
	if((node->type == XML_CDATA_SECTION_NODE) || (node->type == XML_TEXT_NODE)){
		xmlChar *path = xmlGetNodePath(node);
		xmlNodePtr n;
		for(n = node; n; n = n->next){
			if(n->children){
				show(n->children);
			}
		}
		printf("%s -> '%s'\n", path, node->content ? (char *) node->content : "(null)");
		xmlFree(path);
	}
	else if(node->type == XML_ELEMENT_NODE){
		xmlNodePtr n;
		for(n = node; n; n = n->next){
			if(n->children){
				show(n->children);
			}
		}
	}
}

gchar *getCategoryById(Magasin pMagasin, gint Id){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]";
	xmlChar *path;
	gchar *ptrCategory;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	ptrCategory = (gchar*)g_malloc(sizeof(gchar)*50);
	
	if(path == NULL || ptrCategory == NULL){
		fprintf(stderr, "Impossible d'allouer de la memoire\n");
		xmlFree(path);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	sprintf((char*)path, path_template, Id);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr == 0){
		sprintf(ptrCategory, "%s", "FIN");
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		return ptrCategory;
	}
	
	ptrCategory = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar*)"name");
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
	
	return ptrCategory;
}

gint getIdCategoryByRef(Magasin pMagasin, gchar *pRef){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]";
	xmlChar *path;
	gchar *sText;
	gint cpt;
	gboolean idTrouve;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	
	sText = NULL;
	idTrouve = FALSE;
	cpt = 1;
	do{
		sprintf((char*)path, path_template, cpt);
		xmlobject = xmlXPathEval(path, xmlperms_context);
		
		if(xmlobject->nodesetval->nodeNr != 0){
			sText = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar*)"ref");
			if(strcmp(sText, pRef) == 0){
				idTrouve = TRUE;
			}
			g_free(sText);
		}
		cpt++;
	}while(xmlobject->nodesetval->nodeNr != 0 && idTrouve == FALSE);
	
	if(xmlobject->nodesetval->nodeNr != 0 && idTrouve == TRUE){
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
	
		return cpt-1;
	}
	else{
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		
		return -1;
	}
}

gchar *getRefCategoryById(Magasin pMagasin, gint Id){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]";
	xmlChar *path;
	gchar *pRef;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	
	sprintf((char*)path, path_template, Id);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr == 0){
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	
	pRef = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar*)"ref");
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
	
	return pRef;
}

void addCategoryToMagasin(Magasin pMagasin, gchar *Name){
	gint cpt, idCatLast;
	gchar *pRef, *tmp;
	xmlNodePtr NewNode, Node;
	
	/* Creation d'une reference unique */
	cpt=0;
	pRef = g_strdup_printf("%d", cpt);
	while(getIdCategoryByRef(pMagasin, pRef) != -1){
		cpt++;
		g_free(pRef);
		pRef = g_strdup_printf("%d", cpt);
	}
	
	/* Recuperation de l'Id de la derniere categorie */
	idCatLast=1;
	tmp = getCategoryById(pMagasin, idCatLast);
	while(strcmp(tmp, "FIN") != 0){
		idCatLast++;
		g_free(tmp);
		tmp = getCategoryById(pMagasin, idCatLast);
	}
	g_free(tmp);
	
	/* Creation du nouveau node */
	NewNode = xmlNewNode(NULL, (const xmlChar *)"category");
	xmlSetProp(NewNode, (const xmlChar *)"name", (const xmlChar *)Name);
	xmlSetProp(NewNode, (const xmlChar *)"ref", (const xmlChar *)pRef);
	
	/* Initialisation de XPath */
	xmlXPathInit();
	/* Creation de context */
	xmlXPathContextPtr ctxt = xmlXPathNewContext(pMagasin);
	/* Expression XPath */
	if(idCatLast == 1){
		xmlXPathFreeContext(ctxt);
		Node = pMagasin->children;
		xmlAddChild(Node, NewNode);
	}
	else{
		idCatLast--;
		const gchar path_template[] = "/liste_articles/category[%d]";
		xmlChar *path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
		sprintf((char*)path, path_template, idCatLast);
		xmlXPathObjectPtr xpathRes = xmlXPathEval(path, ctxt);
		if(xpathRes->nodesetval->nodeNr != 0){
			Node = xpathRes->nodesetval->nodeTab[0];
			xmlAddNextSibling(Node, NewNode);
		}
		xmlFree(path);
		xmlXPathFreeObject(xpathRes);
		xmlXPathFreeContext(ctxt);
	}
	
	g_free(pRef);
}

void addSSCategoryToMagasin(Magasin pMagasin, gint idCat, gchar *Name){
	gint cpt, idSSCatLast;
	gchar *pRef, *tmp;
	xmlNodePtr NewNode, Node;
	
	/* Creation d'une reference unique */
	cpt=0;
	pRef = g_strdup_printf("%d", cpt);
	while(getIdSSCategoryByRef(pMagasin, idCat, pRef) != -1){
		cpt++;
		g_free(pRef);
		pRef = g_strdup_printf("%d", cpt);
	}
	
	/* Recuperation de l'Id de la derniere categorie */
	idSSCatLast=1;
	tmp = getSousCategoryByCategory(pMagasin, idCat, idSSCatLast);
	while(strcmp(tmp, "FIN") != 0){
		idSSCatLast++;
		g_free(tmp);
		tmp = getSousCategoryByCategory(pMagasin, idCat, idSSCatLast);
	}
	g_free(tmp);
	
	/* Creation du nouveau node */
	NewNode = xmlNewNode(NULL, (const xmlChar *)"sous_category");
	xmlSetProp(NewNode, (const xmlChar *)"name", (const xmlChar *)Name);
	xmlSetProp(NewNode, (const xmlChar *)"ref", (const xmlChar *)pRef);
	
	/* Initialisation de XPath */
	xmlXPathInit();
	/* Creation de context */
	xmlXPathContextPtr ctxt = xmlXPathNewContext(pMagasin);
	/* Expression XPath */
	if(idSSCatLast == 1){
		const gchar path_template[] = "/liste_articles/category[%d]";
		xmlChar *path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
		sprintf((char*)path, path_template, idCat);
		xmlXPathObjectPtr xpathRes = xmlXPathEval(path, ctxt);
		if(xpathRes->nodesetval->nodeNr != 0){
			Node = xpathRes->nodesetval->nodeTab[0];
			xmlAddChild(Node, NewNode);
		}
		xmlFree(path);
		xmlXPathFreeObject(xpathRes);
		xmlXPathFreeContext(ctxt);
	}
	else{
		idSSCatLast--;
		const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]";
		xmlChar *path = (xmlChar*)malloc(sizeof(path_template)+2*sizeof(int));
		sprintf((char*)path, path_template, idCat, idSSCatLast);
		xmlXPathObjectPtr xpathRes = xmlXPathEval(path, ctxt);
		if(xpathRes->nodesetval->nodeNr != 0){
			Node = xpathRes->nodesetval->nodeTab[0];
			xmlAddNextSibling(Node, NewNode);
		}
		xmlFree(path);
		xmlXPathFreeObject(xpathRes);
		xmlXPathFreeContext(ctxt);
	}
	
	g_free(pRef);
}

void addArticleToMagasin(Magasin pMagasin, gint idCat, gint idSSCat, gchar *Name, gchar *Prix){
	gint cpt, idArtLast;
	gchar *pRef, *tmp;
	xmlNodePtr NewNode, Node, NodeName, NodePrix;
	
	/* Creation d'une reference unique */
	cpt=0;
	pRef = g_strdup_printf("%d", cpt);
	while(getIdArticleByRef(pMagasin, idCat, idSSCat, pRef) != -1){
		cpt++;
		g_free(pRef);
		pRef = g_strdup_printf("%d", cpt);
	}
	
	/* Recuperation de l'Id de la derniere categorie */
	idArtLast=1;
	tmp = getArticleNameBySousCategory(pMagasin, idCat, idSSCat, idArtLast);
	while(strcmp(tmp, "FIN") != 0){
		idArtLast++;
		g_free(tmp);
		tmp = getArticleNameBySousCategory(pMagasin, idCat, idSSCat, idArtLast);
	}
	g_free(tmp);
	
	/* Creation du nouveau node */
	NewNode = xmlNewNode(NULL, (const xmlChar *)"article");
	xmlSetProp(NewNode, (const xmlChar *)"ref", (const xmlChar *)pRef);
	/* Ajout des nodes fils */
	NodeName = xmlNewChild(NewNode, NULL, (const xmlChar *)"name", (const xmlChar *)Name);
	NodePrix = xmlNewChild(NewNode, NULL, (const xmlChar *)"prix", (const xmlChar *)Prix);
	
	/* Initialisation de XPath */
	xmlXPathInit();
	/* Creation de context */
	xmlXPathContextPtr ctxt = xmlXPathNewContext(pMagasin);
	/* Expression XPath */
	if(idArtLast == 1){
		const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]";
		xmlChar *path = (xmlChar*)malloc(sizeof(path_template)+2*sizeof(int));
		sprintf((char*)path, path_template, idCat, idSSCat);
		xmlXPathObjectPtr xpathRes = xmlXPathEval(path, ctxt);
		if(xpathRes->nodesetval->nodeNr != 0){
			Node = xpathRes->nodesetval->nodeTab[0];
			xmlAddChild(Node, NewNode);
		}
		xmlFree(path);
		xmlXPathFreeObject(xpathRes);
		xmlXPathFreeContext(ctxt);
	}
	else{
		idArtLast--;
		const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]/article[%d]";
		xmlChar *path = (xmlChar*)malloc(sizeof(path_template)+3*sizeof(int));
		sprintf((char*)path, path_template, idCat, idSSCat, idArtLast);
		xmlXPathObjectPtr xpathRes = xmlXPathEval(path, ctxt);
		if(xpathRes->nodesetval->nodeNr != 0){
			Node = xpathRes->nodesetval->nodeTab[0];
			xmlAddNextSibling(Node, NewNode);
		}
		xmlFree(path);
		xmlXPathFreeObject(xpathRes);
		xmlXPathFreeContext(ctxt);
	}
	
	g_free(pRef);
}

void removeCategoryToMagasin(Magasin pMagasin, gint idCat){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]";
	xmlChar *path;
	xmlNodePtr nodeCur;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	
	sprintf((char*)path, path_template, idCat);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr != 0){
		nodeCur = xmlobject->nodesetval->nodeTab[0];
		xmlUnlinkNode(nodeCur);
	}
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
}

void removeSSCategoryToMagasin(Magasin pMagasin, gint idCat, gint idSSCat){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]";
	xmlChar *path;
	xmlNodePtr nodeCur;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+2*sizeof(int));
	
	sprintf((char*)path, path_template, idCat, idSSCat);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr != 0){
		nodeCur = xmlobject->nodesetval->nodeTab[0];
		xmlUnlinkNode(nodeCur);
	}
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
}

void removeArticleToMagasin(Magasin pMagasin, gint idCat, gint idSSCat, gint idArt){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]/article[%d]";
	xmlChar *path;
	xmlNodePtr nodeCur;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+3*sizeof(int));
	
	sprintf((char*)path, path_template, idCat, idSSCat, idArt);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr != 0){
		nodeCur = xmlobject->nodesetval->nodeTab[0];
		xmlUnlinkNode(nodeCur);
	}
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
}

void modifyCategoryToMagasin(Magasin pMagasin, gchar *NewName, gint idCat){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]";
	xmlChar *path;
	xmlNodePtr nodeCur;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	
	sprintf((char*)path, path_template, idCat);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr != 0){
		nodeCur = xmlobject->nodesetval->nodeTab[0];
		xmlSetProp(nodeCur, (const xmlChar*)"name", (const xmlChar*)NewName);
	}
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
}

void modifySSCategoryToMagasin(Magasin pMagasin, gchar *NewName, gint idCat, gint idSSCat){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]";
	xmlChar *path;
	xmlNodePtr nodeCur;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+2*sizeof(int));
	
	sprintf((char*)path, path_template, idCat, idSSCat);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr != 0){
		nodeCur = xmlobject->nodesetval->nodeTab[0];
		xmlSetProp(nodeCur, (const xmlChar*)"name", (const xmlChar*)NewName);
	}
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
}

void modifyArticleToMagasin(Magasin pMagasin, gchar *NewName, gchar *NewPrix, gint idCat, gint idSSCat, gint idArt){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]/article[%d]";
	xmlChar *path;
	xmlNodePtr nodeCur, Node;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+3*sizeof(int));
	
	sprintf((char*)path, path_template, idCat, idSSCat, idArt);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr != 0){
		nodeCur = xmlobject->nodesetval->nodeTab[0];
		Node = nodeCur->children;
		xmlNodeSetContent(Node, (const xmlChar *)NewName);
		Node = Node->next;
		xmlNodeSetContent(Node, (const xmlChar *)NewPrix);
	}
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
}

gchar *getSousCategoryByCategory(Magasin pMagasin, gint IdCat, gint IdSSCat){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]";
	xmlChar *path;
	gchar *ptrSSCategory;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	ptrSSCategory = (gchar*)g_malloc(sizeof(gchar)*50);
	
	if(path == NULL || ptrSSCategory == NULL){
		fprintf(stderr, "Impossible d'allouer de la memoire\n");
		xmlFree(path);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	sprintf((char*)path, path_template, IdCat, IdSSCat);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr == 0){
		sprintf(ptrSSCategory, "%s", "FIN");
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		return ptrSSCategory;
	}
	
	ptrSSCategory = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar *) "name");
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
	
	return ptrSSCategory;
}

gint getIdSSCategoryByRef(Magasin pMagasin, gint IdCat, gchar *pRef){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]";
	xmlChar *path;
	gchar *sText;
	gboolean idTrouve;
	gint cpt;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	
	sText = NULL;
	idTrouve = FALSE;
	cpt = 1;
	do{
		sprintf((char*)path, path_template, IdCat, cpt);
		xmlobject = xmlXPathEval(path, xmlperms_context);
		
		if(xmlobject->nodesetval->nodeNr != 0){
			sText = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar*)"ref");
			if(strcmp(sText, pRef) == 0){
				idTrouve = TRUE;
			}
			g_free(sText);
		}
		cpt++;
	}while(xmlobject->nodesetval->nodeNr != 0 && idTrouve == FALSE);
	
	if(xmlobject->nodesetval->nodeNr != 0 && idTrouve == TRUE){
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
	
		return cpt-1;
	}
	else{
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		
		return -1;
	}
}

gchar *getRefSSCategoryById(Magasin pMagasin, gint IdCat, gint IdSSCat){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]";
	xmlChar *path;
	gchar *pRef;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	
	sprintf((char*)path, path_template, IdCat, IdSSCat);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(xmlobject->nodesetval->nodeNr == 0){
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	
	pRef = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar *) "ref");
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
	
	return pRef;
}

gchar *getArticleNameBySousCategory(Magasin pMagasin, gint IdCat, gint IdSSCat, gint IdArt){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]/article[%d]/name/text()";
	xmlChar *path;
	gchar *ptrNameCategory;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	ptrNameCategory = (gchar*)g_malloc(sizeof(gchar)*50);
	
	if(path == NULL || ptrNameCategory == NULL){
		fprintf(stderr, "Impossible d'allouer de la memoire\n");
		xmlFree(path);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	sprintf((char*)path, path_template, IdCat, IdSSCat, IdArt);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(!(xmlobject->nodesetval)){
		sprintf(ptrNameCategory, "%s", "FIN");
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		return ptrNameCategory;
	}
	
	sprintf(ptrNameCategory, (char *)xmlobject->nodesetval->nodeTab[0]->content);
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
	
	return ptrNameCategory;
}

gchar *getRefArt(Magasin pMagasin, gint IdCat, gint IdSSCat, gint IdArt){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]/article[%d]";
	xmlChar *path;
	gchar *RefArt;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	RefArt = (gchar*)g_malloc(sizeof(gchar)*50);
	
	if(path == NULL || RefArt == NULL){
		fprintf(stderr, "Impossible d'allouer de la memoire\n");
		xmlFree(path);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	sprintf((char*)path, path_template, IdCat, IdSSCat, IdArt);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(!(xmlobject->nodesetval)){
		fprintf(stderr, "Article introuvable\n");
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	
	RefArt = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar *) "ref");
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
	
	return RefArt;
}

gint getIdArticleByRef(Magasin pMagasin, gint IdCat, gint IdSSCat, gchar *pRef){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const gchar path_template[] = "/liste_articles/category[%d]/sous_category[%d]/article[%d]";
	xmlChar *path;
	gchar *sText;
	gboolean idTrouve;
	gint cpt;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+3*sizeof(int));
	
	sText = NULL;
	idTrouve = FALSE;
	cpt = 1;
	do{
		sprintf((char*)path, path_template, IdCat, IdSSCat, cpt);
		xmlobject = xmlXPathEval(path, xmlperms_context);
		
		if(xmlobject->nodesetval->nodeNr != 0){
			sText = (gchar*)xmlGetProp(xmlobject->nodesetval->nodeTab[0], (const xmlChar*)"ref");
			if(strcmp(sText, pRef) == 0){
				idTrouve = TRUE;
			}
			g_free(sText);
		}
		cpt++;
	}while(xmlobject->nodesetval->nodeNr != 0 && idTrouve == FALSE);
	
	if(xmlobject->nodesetval->nodeNr != 0 && idTrouve == TRUE){
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
	
		return cpt-1;
	}
	else{
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		
		return -1;
	}
}

gchar *getArticlePriceBySousCategory(Magasin pMagasin, gint IdCat, gint IdSSCat, gint IdArt){
	xmlXPathContextPtr xmlperms_context = NULL;
	xmlXPathObjectPtr xmlobject;
	const char path_template[] = "/liste_articles/category[%d]/sous_category[%d]/article[%d]/prix/text()";
	xmlChar *path;
	gchar *ptrPriceCategory;
	
	xmlXPathInit();
	xmlperms_context = xmlXPathNewContext(pMagasin);
	
	path = (xmlChar*)malloc(sizeof(path_template)+sizeof(int));
	ptrPriceCategory = (gchar*)g_malloc(sizeof(gchar)*50);
	
	if(path == NULL || ptrPriceCategory == NULL){
		fprintf(stderr, "Impossible d'allouer de la memoire\n");
		xmlFree(path);
		xmlXPathFreeContext(xmlperms_context);
		return NULL;
	}
	sprintf((char*)path, path_template, IdCat, IdSSCat, IdArt);
	xmlobject = xmlXPathEval(path, xmlperms_context);
	
	if(!(xmlobject->nodesetval)){
		sprintf(ptrPriceCategory, "%s", "FIN");
		xmlFree(path);
		xmlXPathFreeObject(xmlobject);
		xmlXPathFreeContext(xmlperms_context);
		return ptrPriceCategory;
	}
	
	sprintf(ptrPriceCategory, (char *)xmlobject->nodesetval->nodeTab[0]->content);
	
	xmlFree(path);
	xmlXPathFreeObject(xmlobject);
	xmlXPathFreeContext(xmlperms_context);
	
	return ptrPriceCategory;
}

void getIdSSCatByName(Magasin pMagasin, gchar *SearchNameSSCat, gint *IdCat, gint *IdSSCat){
	int cpt1, cpt2;
	char *ptrCategory = NULL;
	char *ptrSSCategory = NULL;
	gboolean SSCatTrouvee;
	
	*IdCat = 0;
	*IdSSCat = 0;
	
	SSCatTrouvee = FALSE;
	
	cpt1 = 1;
	do{
		ptrCategory = getCategoryById(pMagasin, cpt1);
		if(strcmp(ptrCategory, "FIN") != 0){
		
		cpt2 = 1;
		do{
			ptrSSCategory = getSousCategoryByCategory(pMagasin, cpt1, cpt2);
			if(strcmp(ptrSSCategory, "FIN") != 0){			
				if(strcmp(ptrSSCategory, SearchNameSSCat) == 0){
					SSCatTrouvee = TRUE;
					*IdCat = cpt1;
					*IdSSCat = cpt2;
				}
			}
			cpt2++;
		}while(strcmp(ptrSSCategory, "FIN") != 0 || SSCatTrouvee != TRUE);
		}	
		cpt1++;
	}while(strcmp(ptrCategory, "FIN") != 0 || SSCatTrouvee != TRUE);
	
	free(ptrCategory);
	free(ptrSSCategory);
}

void freeMagasin(Magasin pMagasin){
	xmlFreeDoc(pMagasin);
}
