/*
	main.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>
#include <gtk/gtk.h>

#include "main.h"
#include "magasin.h"
#include "lda.h"
#include "interface.h"

int main(int argc, char **argv){
	glda *pGlda;
	/*printf("=== glda v%s ===\n\n", VERSION_GLDA);*/
	
	/*** Initialisation de Gtkk++ ***/
	/*printf("Initialisation de Gtk++...\n");*/
	gtk_init(&argc, &argv);
	
	pGlda = initGlda(argv[1]);
	if(pGlda == NULL){
		return EXIT_FAILURE;
	}
	
	/*** Ouverture de la fenêtre  ***/
	/*printf("Ouverture de la fenêtre...\n");*/
	gtk_widget_show_all(pGlda->pWindow);
	
	if(pGlda->fichierLDA != NULL){
		openLDA(pGlda);
	}
	
	/*** Boucle Gtk++ ***/
	gtk_main();
	
	/*** Liberation de la mémoire ***/
	freeGlda(pGlda);

	return EXIT_SUCCESS;
}

glda *initGlda(gchar *argv){
	glda *pGlda;
	gchar *pText;
	
	/*** Allocation de la mémoire ***/
	pGlda = (glda *)malloc(sizeof(glda));
	if(pGlda == NULL){
		fprintf(stderr, "Impossible d'initialiser Glda...\n");
		return NULL;
	}
	
	/*** Version glda ***/
	strcpy(pGlda->version, VERSION_GLDA);
	
	/*** Chargement des paramètres utilisateurs ***/
	/*printf("Chargement des paramètres utilisateurs\n");*/
	pGlda->pConfig = initConfig();
	if(pGlda->pConfig == NULL){
		free(pGlda);
		return NULL;
	}
	
	/*** Chargement du fichier contenant la liste des articles ***/
	pText = g_key_file_get_string(pGlda->pConfig, "file", "listeFile", NULL);
	/*printf("Chargement du fichier %s\n", pText);*/
	pGlda->pMagasin = initMagasin(pText);
	if(pGlda->pMagasin == NULL){
		free(pGlda);
		g_free(pText);
		return NULL;
	}
	g_free(pText);
	
	/*** Chargement d'un nouveau liste d'achat vide ***/
	/*printf("Chargement de liste d'achat vide\n");*/
	pGlda->pLdaChainee = initLda();
	
	if(argv){
		if(g_file_test(argv, G_FILE_TEST_EXISTS) == TRUE){
			pGlda->pLdaChainee = openListeLDA(pGlda->pLdaChainee, pGlda->pMagasin, argv, pGlda->pConfig);
			if(pGlda->pLdaChainee != NULL){
				pGlda->fichierLDA = g_strdup_printf("%s", argv);
			}
			else{
				fprintf(stderr, "Impossible d'ouvrir le fichier %s\n", argv);
				/** On ne met pas NULL dans fichierLDA pour avoir une boite de dialogue **/
				pGlda->fichierLDA = g_strdup_printf("%s", argv);
			}
		}
		else{
			fprintf(stderr, "Impossible de trouver le fichier %s\n", argv);
			/** On ne met pas NULL dans fichierLDA pour avoir une boite de dialogue **/
			pGlda->fichierLDA = g_strdup_printf("%s", argv);
		}
	}
	else{
		pGlda->fichierLDA = NULL;
	}
	
	/*** Initialisation de la fenêtre ***/
	/*printf("Initialisation de la fenêtre...\n");*/
	create_pWindow(pGlda);
	
	pGlda->save = TRUE;
	
	return pGlda;
}

void freeGlda(glda *pGlda){
	/*printf("Libération de la mémoire...\n");*/
	freeConfig(pGlda->pConfig);
	freeMagasin(pGlda->pMagasin);
	if(pGlda->fichierLDA != NULL)
		g_free(pGlda->fichierLDA);
	freeLdaChainee(pGlda->pLdaChainee);
	
	free(pGlda);
}
