/*
	preferencesCallbacks.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>
#include <gtk/gtk.h>

#include "main.h"
#include "interface.h"

void OnChangedLangue(GtkWidget *pEntry, Preferences *pPreferencesData){
	const gchar *pLangue;
	
	pLangue = gtk_entry_get_text(GTK_ENTRY(pEntry));
	
	pPreferencesData->configModif = TRUE;
	
	g_key_file_set_string(pPreferencesData->pGlda->pConfig, "general", "lang", pLangue);
}

void OnChangedDevise(GtkWidget *pEntry, Preferences *pPreferencesData){
	const gchar *pDevise;
	
	pDevise = gtk_entry_get_text(GTK_ENTRY(pEntry));
	
	pPreferencesData->configModif = TRUE;
	
	g_key_file_set_string(pPreferencesData->pGlda->pConfig, "general", "devise", pDevise);
}

void OnChangedListe(GtkWidget *pEntry, Preferences *pPreferencesData){
	const gchar *pListe;
	
	pListe = gtk_entry_get_text(GTK_ENTRY(pEntry));
	
	pPreferencesData->configModif = TRUE;
	
	g_key_file_set_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", pListe);
}

void OnOpenListe(GtkWidget *pButton, Preferences *pPreferencesData){
	modifyFileXml(pPreferencesData);
}

void OnClearCat(GtkWidget *pButton, Preferences *pPreferencesData){
	gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryCat), "");
}

void OnClearSSCat(GtkWidget *pButton, Preferences *pPreferencesData){
	gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntrySSCat), "");
	gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1), -1);
}

void OnClearArt(GtkWidget *pButton, Preferences *pPreferencesData){
	gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryArtName), "");
	gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryArtPrice), "");
	gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2), -1);
	gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat), -1);
}

void OnAddCat(GtkWidget *pButton, Preferences *pPreferencesData){
	const gchar *pCat;
	/*gchar *pFicXml;*/
	
	pCat = gtk_entry_get_text(GTK_ENTRY(pPreferencesData->pEntryCat));
	if(strcmp(pCat, "") !=0 ){
		addCategoryToMagasin(pPreferencesData->pGlda->pMagasin, (gchar*)pCat);
		addCategoryToInterface(pPreferencesData, (gchar*)pCat);
		
		pPreferencesData->listeModif = TRUE;
		/*pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
		xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8" ,1);*/
		
		gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryCat), "");
	}
}

void OnAddSSCat(GtkWidget *pButton, Preferences *pPreferencesData){
	gchar *ptrCategory;
	const gchar *pSSCat;
	gint idCat;
	/*gchar *pFicXml;*/
	
	idCat = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1));
	pSSCat = gtk_entry_get_text(GTK_ENTRY(pPreferencesData->pEntrySSCat));
	if(idCat != -1 && strcmp(pSSCat, "") != 0){
		idCat++;
		ptrCategory = getCategoryById(pPreferencesData->pGlda->pMagasin, idCat);
		
		addSSCategoryToMagasin(pPreferencesData->pGlda->pMagasin, idCat, (gchar*)pSSCat);
		addSSCategoryToInterface(pPreferencesData, idCat, (gchar*)pSSCat);
		g_free(ptrCategory);
		
		pPreferencesData->listeModif = TRUE;
		/*pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
		xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8", 1);*/
		
		gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntrySSCat), "");
		gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1), -1);
	}
}

void OnAddArt(GtkWidget *pButton, Preferences *pPreferencesData){
	gint idCat, idSSCat;
	gdouble Prix;
	const gchar *pArtName, *pArtPrix;
	/*gchar *pFicXml;*/
	gchar *pPrix;
	
	idCat = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2));
	idSSCat = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat));
	pArtName = gtk_entry_get_text(GTK_ENTRY(pPreferencesData->pEntryArtName));
	pArtPrix = gtk_entry_get_text(GTK_ENTRY(pPreferencesData->pEntryArtPrice));
	Prix = strtod(pArtPrix, NULL);
	pPrix = g_strdup_printf("%.2f", Prix);
	
	if(idCat != -1 && idSSCat != -1 && strcmp(pArtName, "") != 0 && strcmp(pArtPrix, "") != 0 && Prix != 0){
		idCat++;
		idSSCat++;
		
		addArticleToMagasin(pPreferencesData->pGlda->pMagasin, idCat, idSSCat, (gchar*)pArtName, (gchar*)pPrix);
		addArticleToInterface(pPreferencesData, idCat, idSSCat, (gchar*)pArtName, (gchar*)pPrix);
		
		pPreferencesData->listeModif = TRUE;
		/*pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
		xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8", 1);*/
	
		gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryArtName), "");
		gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryArtPrice), "");
		gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2), -1);
		gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat), -1);
	}
	g_free(pPrix);
}

void OnChangeListeCategory(GtkWidget *pComboBox, Preferences *pPreferencesData){
	gint i;
	
	i = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2));
	
	i++;
	change_pListeDeroulanteSSCat(pPreferencesData, i);
}

void OnRemoveToMagasin(GtkWidget *pButton, Preferences *pPreferencesData){
	GList *list;
	gint imb;
	gint *tab = NULL;
	/*gchar *pFicXml;*/
	GtkWidget *pDialog = NULL;
	
	list = gtk_tree_selection_get_selected_rows(pPreferencesData->selectMagasin, NULL);
	if(list != NULL){
		/* Creation de la boite de message */
		pDialog = gtk_message_dialog_new(GTK_WINDOW(pPreferencesData->pGlda->pWindow),
						GTK_DIALOG_MODAL,
						GTK_MESSAGE_QUESTION,
						GTK_BUTTONS_YES_NO,
						"Voulez-vous supprimer l'élément sélectionné?");
		
		/* Affichage et attente d une reponse */
		switch(gtk_dialog_run(GTK_DIALOG(pDialog))){
			case GTK_RESPONSE_YES:
				gtk_widget_destroy(pDialog);
				/* Niveau d'imbrication */
				imb = gtk_tree_path_get_depth(list->data);
				switch(imb){
				/* Une catégorie est sélectionnée */
				case 1:
					tab = gtk_tree_path_get_indices(list->data);
					removeCategoryToMagasin(pPreferencesData->pGlda->pMagasin, tab[0]+1);
					removeCategoryToInterface(pPreferencesData, tab[0]);
					
					pPreferencesData->listeModif = TRUE;
					/*pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
					xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8", 1);*/
					break;
				/* Une sous catégorie est sélectionnée */
				case 2:
					tab = gtk_tree_path_get_indices(list->data);
					removeSSCategoryToMagasin(pPreferencesData->pGlda->pMagasin, tab[0]+1, tab[1]+1);
					removeSSCategoryToInterface(pPreferencesData, tab[0], tab[1]);
					
					pPreferencesData->listeModif = TRUE;
					/*pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
					xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8", 1);*/
					break;
				/* Un article est sélectionné */
				case 3:
					tab = gtk_tree_path_get_indices(list->data);
					removeArticleToMagasin(pPreferencesData->pGlda->pMagasin, tab[0]+1, tab[1]+1, tab[2]+1);
					removeArticleToInterface(pPreferencesData, tab[0], tab[1], tab[2]);
					
					pPreferencesData->listeModif = TRUE;
					/*pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
					xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8", 1);*/
					break;
				default:
					break;
				}
				break;
			case GTK_RESPONSE_NO:
				gtk_widget_destroy(pDialog);
				break;
			default:
				gtk_widget_destroy(pDialog);
				break;
		}
		g_list_free(list);
		free(tab);
	}
}

void OnEditList(GtkWidget *pButton, Preferences *pPreferencesData){
	GList *list;
	gint imb;
	gint *tab = NULL;
	/*gchar *Name = NULL;
	gchar *Prix = NULL;*/
	
	list = gtk_tree_selection_get_selected_rows(pPreferencesData->selectMagasin, NULL);
	if(list != NULL){
		/* Niveau d'imbrication */
		imb = gtk_tree_path_get_depth(list->data);
		switch(imb){
			/* Une catégorie est sélectionnée */
			case 1:
				tab = gtk_tree_path_get_indices(list->data);
				editCategory(pPreferencesData, tab[0]);
				/*Name = getCategoryById(pPreferencesData->pGlda->pMagasin, tab[0]+1);
				
				gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryCat), Name);
				
				pPreferencesData->addCat = FALSE;
				pPreferencesData->idCatToModif = tab[0];
				
				g_free(Name);*/
				break;
			/* Une sous catégorie est sélectionnée */
			case 2:
				tab = gtk_tree_path_get_indices(list->data);
				
				editSSCategory(pPreferencesData, tab[0], tab[1]);
				/*Name = getSousCategoryByCategory(pPreferencesData->pGlda->pMagasin, tab[0]+1, tab[1]+1);
				
				gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntrySSCat), Name);
				gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1), tab[0]);
				
				pPreferencesData->addSSCat = FALSE;
				pPreferencesData->idCatToModif = tab[0];
				pPreferencesData->idSSCatToModif = tab[1];
				
				g_free(Name);*/
				break;
			/* Un article est sélectionné */
			case 3:
				tab = gtk_tree_path_get_indices(list->data);
				
				editArticle(pPreferencesData, tab[0], tab[1], tab[2]);
				/*Name = getArticleNameBySousCategory(pPreferencesData->pGlda->pMagasin, tab[0]+1, tab[1]+1, tab[2]+1);
				Prix = getArticlePriceBySousCategory(pPreferencesData->pGlda->pMagasin, tab[0]+1, tab[1]+1, tab[2]+1);
				
				gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryArtName), Name);
				gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryArtPrice), Prix);
				gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2), tab[0]);
				gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat), tab[1]);
				
				pPreferencesData->addArt = FALSE;
				pPreferencesData->idCatToModif = tab[0];
				pPreferencesData->idSSCatToModif = tab[1];
				pPreferencesData->idArtToModif = tab[2];
				
				g_free(Name);
				g_free(Prix);*/
				break;
			default:
				break;
			
		}
		g_list_free(list);
		free(tab);
	}
}
