/*
	preferencesInterface.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>
#include <gtk/gtk.h>

#include "main.h"
#include "interface.h"

void create_pPreferences(glda *pGlda){
	GtkWidget *pPreferences;
	GtkWidget *pNotebook;
	GtkWidget *pGeneral;
	GtkWidget *pModifListe;
	GtkWidget *pTabLabel;
	GtkWidget *pDialog;
	Preferences *pPreferencesData;
	gchar *pText;
	gchar *pFicXml;
	gchar *fileUserConfig;
	FILE* fichier = NULL;
	
	pPreferencesData = (Preferences *) malloc(sizeof(Preferences));
	
	pPreferencesData->pGlda = pGlda;
	
	pPreferencesData->configModif = FALSE;
	pPreferencesData->listeModif = FALSE;
	
	pPreferences = gtk_dialog_new_with_buttons("Préférences", GTK_WINDOW(pGlda->pWindow), GTK_DIALOG_MODAL,
											GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
											NULL);

	/*** Creation de GtkNotebook ***/
	pNotebook = gtk_notebook_new();
	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(pPreferences)->vbox), pNotebook, TRUE, FALSE, 0);
	/* Position des onglets : en haut */
	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(pNotebook), GTK_POS_TOP);
	/* Ajout des boutons de navigation */
	gtk_notebook_set_scrollable(GTK_NOTEBOOK(pNotebook), TRUE);
	
	/*** Onglet General ***/
	pGeneral = create_pGeneral(pPreferencesData);
	pTabLabel = gtk_label_new("Général");
	/* Insertion de la page */
	gtk_notebook_append_page(GTK_NOTEBOOK(pNotebook), pGeneral, pTabLabel);
	
	/*** Onglet Modification de la liste */
	pModifListe = create_pModifListe(pPreferencesData);
	pTabLabel = gtk_label_new("Liste d'articles");
	/* Insertion de la page */
	gtk_notebook_append_page(GTK_NOTEBOOK(pNotebook), pModifListe, pTabLabel);
	
	/* Affichage des elements de la boite de dialogue */
	gtk_widget_show_all(GTK_DIALOG(pPreferences)->vbox);
	
	switch(gtk_dialog_run(GTK_DIALOG(pPreferences))){
		case GTK_RESPONSE_CLOSE:
		default:
			gtk_widget_destroy(pPreferences);
			if(pPreferencesData->configModif == TRUE){
				fileUserConfig = g_strdup_printf("%s%s%s", getenv("HOME"), DIR_USER_CONFIG, FILE_USER_CONFIG);
				fichier = fopen(fileUserConfig, "w");
				if(fichier != NULL){
					pText = g_key_file_to_data(pPreferencesData->pGlda->pConfig, NULL, NULL);
					fprintf(fichier, "%s", pText);
					
					pDialog = gtk_message_dialog_new(GTK_WINDOW(pPreferencesData->pGlda->pWindow),
									GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
									"Les modifications seront prises en compte au prochain lancement de Glda");
									
					/* Affichage de la boite de message */
					gtk_dialog_run(GTK_DIALOG(pDialog));
					/* Destruction de la boite de message */
					gtk_widget_destroy(pDialog);
					
					g_free(pText);
					fclose(fichier);
				}
				else{
					fprintf(stderr, "Impossible d'ouvrir le fichier de config : %s\n", fileUserConfig);
				}
				g_free(fileUserConfig);
			}
			if(pPreferencesData->listeModif == TRUE){
				pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
				xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8" ,0);
				g_free(pFicXml);
			}
			break;
	}
	
	g_free(pPreferencesData);
}

GtkWidget *create_pGeneral(Preferences *pPreferencesData){
	GtkWidget *pGeneral;
	GtkWidget *pLabel;
	GtkWidget *pEntry;
	GtkWidget *pButton;
	GtkWidget *pVBox;
	GtkWidget *pHBox;
	
	gchar *sText;
	
	pGeneral = gtk_vbox_new(FALSE, 0);
	
	/** Parametre langue **/
	pVBox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(pGeneral), pVBox, FALSE, FALSE, 10);
	
	pHBox = gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(pVBox), pHBox, FALSE, FALSE, 0);
	
	pLabel = gtk_label_new("Langue :");
	pEntry = gtk_entry_new();
	gtk_entry_set_max_length(GTK_ENTRY(pEntry), 2);
	sText = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "general", "lang", NULL);
	gtk_entry_set_text(GTK_ENTRY(pEntry), sText);
	g_free(sText);
	g_signal_connect(G_OBJECT(pEntry), "changed", G_CALLBACK(OnChangedLangue), (Preferences*) pPreferencesData);
	
	gtk_box_pack_start(GTK_BOX(pHBox), pLabel, FALSE, FALSE, 20);
	gtk_box_pack_start(GTK_BOX(pHBox), pEntry, FALSE, FALSE, 20);
	
	/** Parametre devise **/
	pVBox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(pGeneral), pVBox, FALSE, FALSE, 10);
	
	pHBox = gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(pVBox), pHBox, FALSE, FALSE, 0);
	
	pLabel = gtk_label_new("Devise :");
	pEntry = gtk_entry_new();
	sText = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "general", "devise", NULL);
	gtk_entry_set_text(GTK_ENTRY(pEntry), sText);
	g_free(sText);
	g_signal_connect(G_OBJECT(pEntry), "changed", G_CALLBACK(OnChangedDevise), (Preferences*) pPreferencesData);
	
	gtk_box_pack_start(GTK_BOX(pHBox), pLabel, FALSE, FALSE, 20);
	gtk_box_pack_start(GTK_BOX(pHBox), pEntry, FALSE, FALSE, 20);
	
	/** Parametre liste d'articles **/
	pVBox = gtk_vbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(pGeneral), pVBox, FALSE, FALSE, 10);
	
	pHBox = gtk_hbox_new(FALSE, 0);
	gtk_box_pack_start(GTK_BOX(pVBox), pHBox, FALSE, FALSE, 0);
	
	pLabel = gtk_label_new("Liste :");
	pPreferencesData->pEntryListe = gtk_entry_new();
	sText = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
	gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryListe), sText);
	gtk_editable_set_editable(GTK_EDITABLE(pPreferencesData->pEntryListe), FALSE);
	g_free(sText);
	g_signal_connect(G_OBJECT(pPreferencesData->pEntryListe), "changed", G_CALLBACK(OnChangedListe), (Preferences*) pPreferencesData);
	
	pButton = gtk_button_new_from_stock(GTK_STOCK_OPEN);
	g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnOpenListe), (Preferences*) pPreferencesData);
	gtk_box_pack_start(GTK_BOX(pHBox), pLabel, FALSE, FALSE, 20);
	gtk_box_pack_start(GTK_BOX(pHBox), pPreferencesData->pEntryListe, FALSE, FALSE, 0);
	gtk_box_pack_start(GTK_BOX(pHBox), pButton, FALSE, FALSE, 0);
	
	return pGeneral;
}

GtkWidget *create_pModifListe(Preferences *pPreferencesData){
	GtkWidget *pModifListe;
	GtkWidget *pEdition;
	GtkWidget *pScrollbar;
	GtkWidget *pTreeView;
	GtkWidget *pHBox;
	GtkWidget *pVBox;
	GtkWidget *pButton;
	
	/*GtkTreeStore *pTreeStore;*/
	GtkTreeViewColumn *pColumn;
        GtkCellRenderer *pCellRenderer;
        
	pModifListe = gtk_table_new(1, 2, TRUE);
	
	/** Partie Edition **/
        pEdition = create_pEdition(pPreferencesData);
        gtk_table_attach_defaults(GTK_TABLE(pModifListe), pEdition, 0, 1, 0, 1);
        
        /** Partie Liste **/
        pVBox = gtk_vbox_new(FALSE, 10);
        gtk_table_attach_defaults(GTK_TABLE(pModifListe), pVBox, 1, 2, 0, 1);
        
        pScrollbar = gtk_scrolled_window_new(NULL, NULL);
        gtk_box_pack_start(GTK_BOX(pVBox), pScrollbar, TRUE, TRUE, 0);
        
        pPreferencesData->pTreeStore = create_pListeCatEdition(pPreferencesData);
        
        pTreeView = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pPreferencesData->pTreeStore));
        
        /* Donner la possibilité de simple selection */
	pPreferencesData->selectMagasin = gtk_tree_view_get_selection(GTK_TREE_VIEW(pTreeView));
	gtk_tree_selection_set_mode(pPreferencesData->selectMagasin, GTK_SELECTION_SINGLE);
	
        pCellRenderer = gtk_cell_renderer_text_new();
	pColumn = gtk_tree_view_column_new_with_attributes("Articles", pCellRenderer, "text", PRODUITS_COLUMN, NULL);
	gtk_tree_view_column_set_resizable(pColumn, TRUE);
	gtk_tree_view_append_column(GTK_TREE_VIEW(pTreeView), pColumn);
	
	pCellRenderer = gtk_cell_renderer_text_new();
	pColumn = gtk_tree_view_column_new_with_attributes("Prix", pCellRenderer, "text", PRIX_COLUMN, NULL);
	gtk_tree_view_column_set_resizable(pColumn, TRUE);
	gtk_tree_view_append_column(GTK_TREE_VIEW(pTreeView), pColumn);
	
        gtk_container_add(GTK_CONTAINER(pScrollbar), pTreeView);
        
        pHBox = gtk_hbox_new(TRUE, 0);
        pButton = gtk_button_new_from_stock(GTK_STOCK_DELETE);
        g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnRemoveToMagasin), (Preferences*)pPreferencesData);
        gtk_box_pack_start(GTK_BOX(pHBox), pButton, TRUE, TRUE, 0);
        pButton = gtk_button_new_from_stock(GTK_STOCK_EDIT);
        g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnEditList), (Preferences*)pPreferencesData);
        gtk_box_pack_start(GTK_BOX(pHBox), pButton, TRUE, TRUE, 0);
        gtk_box_pack_start(GTK_BOX(pVBox), pHBox, FALSE, FALSE, 0);

	return pModifListe;
}

GtkWidget *create_pEdition(Preferences *pPreferencesData){
	GtkWidget *pEdition;
	GtkWidget *pFrame;
	GtkWidget *pTable;
	GtkWidget *pLabel;
	GtkWidget *pButton;
	gint i;
	
	pEdition = gtk_vbox_new(TRUE, 0);
	
	/** Partie categorie **/
	pFrame = gtk_frame_new("Catégorie");
	gtk_box_pack_start(GTK_BOX(pEdition), pFrame, TRUE, FALSE, 0);
	
	pTable = gtk_table_new(2, 2, TRUE);
	
	pLabel = gtk_label_new("Nom :");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 0, 1);
	pPreferencesData->pEntryCat = gtk_entry_new();
	gtk_table_attach_defaults(GTK_TABLE(pTable), pPreferencesData->pEntryCat, 1, 2, 0, 1);
	
	pButton = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
	g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnClearCat), (Preferences *)pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pButton, 0, 1, 1, 2);
	
	pButton = gtk_button_new_from_stock(GTK_STOCK_OK);
	g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnAddCat), (Preferences*)pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pButton, 1, 2, 1, 2);
	
	gtk_container_add(GTK_CONTAINER(pFrame), pTable);
	
	/** Partie sous categorie **/
	pFrame = gtk_frame_new("Sous-catégorie");
	gtk_box_pack_start(GTK_BOX(pEdition), pFrame, TRUE, FALSE, 0);
	
	pTable = gtk_table_new(3, 2, TRUE);
	
	pLabel = gtk_label_new("Catégorie : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 0, 1);
	
	pPreferencesData->pComboBoxCat1 = create_pListeDeroulanteCat(pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pPreferencesData->pComboBoxCat1, 1, 2, 0, 1);
	
	pLabel = gtk_label_new("Nom :");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 1, 2);
	pPreferencesData->pEntrySSCat = gtk_entry_new();
	gtk_table_attach_defaults(GTK_TABLE(pTable), pPreferencesData->pEntrySSCat, 1, 2, 1, 2);
	
	pButton = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
	g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnClearSSCat), (glda *)pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pButton, 0, 1, 2, 3);
	
	pButton = gtk_button_new_from_stock(GTK_STOCK_OK);
	g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnAddSSCat), (Preferences*)pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pButton, 1, 2, 2, 3);
	
	gtk_container_add(GTK_CONTAINER(pFrame), pTable);
	
	/** Partie article **/
	pFrame = gtk_frame_new("Article");
	gtk_box_pack_start(GTK_BOX(pEdition), pFrame, TRUE, FALSE, 0);
	
	pTable = gtk_table_new(5, 2, TRUE);
	
	pLabel = gtk_label_new("Catégorie : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 0, 1);
	
	pPreferencesData->pComboBoxCat2 = create_pListeDeroulanteCat(pPreferencesData);
	g_signal_connect(G_OBJECT(pPreferencesData->pComboBoxCat2), "changed", G_CALLBACK(OnChangeListeCategory), (Preferences*)pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pPreferencesData->pComboBoxCat2, 1, 2, 0, 1);
	
	pLabel = gtk_label_new("Sous-catégorie : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 1, 2);
	
	i = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2));
	i++;
	pPreferencesData->pComboBoxSSCat = create_pListeDeroulanteSSCat(pPreferencesData, i);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pPreferencesData->pComboBoxSSCat, 1, 2, 1, 2);
	
	pLabel = gtk_label_new("Nom :");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 2, 3);
	pPreferencesData->pEntryArtName = gtk_entry_new();
	gtk_table_attach_defaults(GTK_TABLE(pTable), pPreferencesData->pEntryArtName, 1, 2, 2, 3);
	
	pLabel = gtk_label_new("Prix :");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 3, 4);
	pPreferencesData->pEntryArtPrice = gtk_entry_new();
	gtk_table_attach_defaults(GTK_TABLE(pTable), pPreferencesData->pEntryArtPrice, 1, 2, 3, 4);
	
	pButton = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
	g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnClearArt), (glda *)pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pButton, 0, 1, 4, 5);
	
	pButton = gtk_button_new_from_stock(GTK_STOCK_OK);
	g_signal_connect(G_OBJECT(pButton), "clicked", G_CALLBACK(OnAddArt), (Preferences*)pPreferencesData);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pButton, 1, 2, 4, 5);
	
	gtk_container_add(GTK_CONTAINER(pFrame), pTable);
	
	return pEdition;
}

GtkTreeStore *create_pListeCatEdition(Preferences *pPreferencesData){
	GtkTreeStore *pTreeStore;
	
	GtkTreeIter pIter;
        GtkTreeIter pIter2;
        GtkTreeIter pIter3;
        
        gchar *ptrCategory = NULL;
        gchar *ptrSSCategory = NULL;
        gchar *ptrArticleName = NULL;
        gchar *ptrArticlePrix = NULL;
        gint cpt1, cpt2, cpt3;
        
        
	
	pTreeStore = gtk_tree_store_new(N_COLUMN_PRODUITS, G_TYPE_STRING, G_TYPE_STRING);
        
        cpt1 = 1;
	do{
	        if(ptrCategory != NULL)
	        	g_free(ptrCategory);
	        
	        ptrCategory = getCategoryById(pPreferencesData->pGlda->pMagasin, cpt1);
		if(strcmp(ptrCategory, "FIN") != 0){
	        	/* Creation de la nouvelle ligne */
        		gtk_tree_store_append(pTreeStore, &pIter, NULL);
        		/* Mise a jour des donnees */
        		gtk_tree_store_set(pTreeStore, &pIter, PRODUITS_COLUMN, ptrCategory, PRIX_COLUMN, "", -1);
        		
        		cpt2 = 1;
			do{
	        		if(ptrSSCategory != NULL)
					g_free(ptrSSCategory);
					
        			ptrSSCategory = getSousCategoryByCategory(pPreferencesData->pGlda->pMagasin, cpt1, cpt2);
				if(strcmp(ptrSSCategory, "FIN") != 0){
        				/* Creation de la nouvelle ligne enfant */
        				gtk_tree_store_append(pTreeStore, &pIter2, &pIter);
        				
        				/* Mise a jour des donnees */
        				gtk_tree_store_set(pTreeStore, &pIter2, PRODUITS_COLUMN, ptrSSCategory, PRIX_COLUMN, "", -1);
        				
        				cpt3 = 1;
        				do{
        					if(ptrArticleName != NULL)
        						g_free(ptrArticleName);
        					if(ptrArticlePrix != NULL)
        						g_free(ptrArticlePrix);
        						
        					ptrArticleName = getArticleNameBySousCategory(pPreferencesData->pGlda->pMagasin, cpt1, cpt2, cpt3);
        					ptrArticlePrix = getArticlePriceBySousCategory(pPreferencesData->pGlda->pMagasin, cpt1, cpt2, cpt3);
        					if(strcmp(ptrArticleName, "FIN") != 0){
        						/* Creation de la nouvelle ligne enfant */
        						gtk_tree_store_append(pTreeStore, &pIter3, &pIter2);
        						
        						/* Mise a jour des donnees */
        						gtk_tree_store_set(pTreeStore, &pIter3, PRODUITS_COLUMN, ptrArticleName, PRIX_COLUMN, ptrArticlePrix, -1);
        					}
        					cpt3++;
        				}while(strcmp(ptrArticleName, "FIN") != 0);
				}
				cpt2++;
			}while(strcmp(ptrSSCategory, "FIN") != 0);
		}
		cpt1++;
	}while(strcmp(ptrCategory, "FIN") != 0);
	
	g_free(ptrCategory);
	g_free(ptrSSCategory);
	g_free(ptrArticleName);
	g_free(ptrArticlePrix);
	
	return pTreeStore;
}

GtkWidget *create_pListeDeroulanteCat(Preferences *pPreferencesData){
	GtkWidget *pCombo;
	gint cpt;
	gchar *ptrCategory = NULL;
	
	pCombo = gtk_combo_box_new_text();
	
	cpt = 1;
	do{
	        if(ptrCategory != NULL)
	        	g_free(ptrCategory);
	        
	        ptrCategory = getCategoryById(pPreferencesData->pGlda->pMagasin, cpt);
		if(strcmp(ptrCategory, "FIN") != 0){
			gtk_combo_box_append_text(GTK_COMBO_BOX(pCombo), ptrCategory);
		}
		cpt++;
	}while(strcmp(ptrCategory, "FIN") != 0);
	
	g_free(ptrCategory);
	
	return pCombo;
}

GtkWidget *create_pListeDeroulanteSSCat(Preferences *pPreferencesData, gint idCat){
	GtkWidget *pCombo;
	gint cpt;
	gchar *ptrSSCategory = NULL;
	
	pCombo = gtk_combo_box_new_text();
	
	if(idCat == 0){
		return pCombo;
	}
	cpt = 1;
	do{
	        if(ptrSSCategory != NULL)
	        	g_free(ptrSSCategory);
	        
	        ptrSSCategory = getSousCategoryByCategory(pPreferencesData->pGlda->pMagasin, idCat, cpt);
		if(strcmp(ptrSSCategory, "FIN") != 0){
			gtk_combo_box_append_text(GTK_COMBO_BOX(pCombo), ptrSSCategory);
		}
		cpt++;
	}while(strcmp(ptrSSCategory, "FIN") != 0);
	
	g_free(ptrSSCategory);
	
	return pCombo;
}

void change_pListeDeroulanteSSCat(Preferences *pPreferencesData, gint idCat){
	gint cpt, i;
	gchar *ptrSSCategory = NULL;
	
	i = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat));
	if(i == -1){
		i++;
		gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat), i);
		i = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat));
	}
	
	while(i != -1){
		gtk_combo_box_remove_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat), i);
		i = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat));
		if(i == -1){
			i++;
			gtk_combo_box_set_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat), i);
			i = gtk_combo_box_get_active(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat));
		}
	};
	
	if(idCat > 0){
		cpt = 1;
		do{
	        	if(ptrSSCategory != NULL)
	        		g_free(ptrSSCategory);
	        	
	        	ptrSSCategory = getSousCategoryByCategory(pPreferencesData->pGlda->pMagasin, idCat, cpt);
			if(strcmp(ptrSSCategory, "FIN") != 0){
				gtk_combo_box_append_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxSSCat), ptrSSCategory);
			}
			cpt++;
		}while(strcmp(ptrSSCategory, "FIN") != 0);
	
		g_free(ptrSSCategory);
	}
}

void addCategoryToInterface(Preferences *pPreferencesData, gchar *Name){
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(0, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	
	gtk_tree_store_append(pPreferencesData->pTreeStore, &Iter, NULL);
	gtk_tree_store_set(pPreferencesData->pTreeStore, &Iter, PRODUITS_COLUMN, Name, PRIX_COLUMN, "", -1);
	
	pPath = gtk_tree_path_new_from_indices(0, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pGlda->pListCat), &Iter, pPath);
	
	gtk_tree_store_append(pPreferencesData->pGlda->pListCat, &Iter, NULL);
	gtk_tree_store_set(pPreferencesData->pGlda->pListCat, &Iter, MAGASINS_COLUMN, Name, -1);
	
	gtk_combo_box_append_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1), Name);
	gtk_combo_box_append_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2), Name);
}

void addSSCategoryToInterface(Preferences *pPreferencesData, gint idCat, gchar *Name){
	GtkTreeIter Iter;
	GtkTreeIter Iter2;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(idCat-1, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	pPath = gtk_tree_path_new_from_indices(0, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter2, pPath);
	
	gtk_tree_store_append(pPreferencesData->pTreeStore, &Iter2, &Iter);
	gtk_tree_store_set(pPreferencesData->pTreeStore, &Iter2, PRODUITS_COLUMN, Name, PRIX_COLUMN, "", -1);
	
	pPath = gtk_tree_path_new_from_indices(idCat-1, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pGlda->pListCat), &Iter, pPath);
	pPath = gtk_tree_path_new_from_indices(0, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pGlda->pListCat), &Iter2, pPath);
	
	gtk_tree_store_append(pPreferencesData->pGlda->pListCat, &Iter2, &Iter);
	gtk_tree_store_set(pPreferencesData->pGlda->pListCat, &Iter2, MAGASINS_COLUMN, Name, -1);
}

void addArticleToInterface(Preferences *pPreferencesData, gint idCat, gint idSSCat, gchar *Name, gchar *Prix){
	GtkTreeIter Iter;
	GtkTreeIter Iter2;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(idCat-1, idSSCat-1, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	pPath = gtk_tree_path_new_from_indices(0, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter2, pPath);
	
	gtk_tree_store_append(pPreferencesData->pTreeStore, &Iter2, &Iter);
	gtk_tree_store_set(pPreferencesData->pTreeStore, &Iter2, PRODUITS_COLUMN, Name, PRIX_COLUMN, Prix, -1);
}

void removeCategoryToInterface(Preferences *pPreferencesData, gint idCat){
	GtkTreeIter Iter;
	GtkTreePath *pPath = NULL;
	
	pPath = gtk_tree_path_new_from_indices(idCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	gtk_tree_store_remove(pPreferencesData->pTreeStore, &Iter);

	pPath = gtk_tree_path_new_from_indices(idCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pGlda->pListCat), &Iter, pPath);
	gtk_tree_store_remove(pPreferencesData->pGlda->pListCat, &Iter);

	gtk_combo_box_remove_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1), idCat);
	gtk_combo_box_remove_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2), idCat);
}

void removeSSCategoryToInterface(Preferences *pPreferencesData, gint idCat, gint idSSCat){
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(idCat, idSSCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	gtk_tree_store_remove(pPreferencesData->pTreeStore, &Iter);
	
	pPath = gtk_tree_path_new_from_indices(idCat, idSSCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pGlda->pListCat), &Iter, pPath);
	gtk_tree_store_remove(pPreferencesData->pGlda->pListCat, &Iter);
}

void removeArticleToInterface(Preferences *pPreferencesData, gint idCat, gint idSSCat, gint idArt){
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(idCat, idSSCat, idArt, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	gtk_tree_store_remove(pPreferencesData->pTreeStore, &Iter);
}

void editCategory(Preferences *pPreferencesData, gint idCat){
	GtkWidget *pDialog;
	GtkWidget *pTable;
	GtkWidget *pLabel;
	GtkWidget *pEntry;
	gchar *Name = NULL;
	const gchar *NameModify;
	gchar *pFicXml;
	
	Name = getCategoryById(pPreferencesData->pGlda->pMagasin, idCat+1);
	
	/* Creation de la boite de dialogue */
	pDialog = gtk_dialog_new_with_buttons("Modifier la catégorie",
						GTK_WINDOW(pPreferencesData->pGlda->pWindow),
						GTK_DIALOG_MODAL,
						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
						GTK_STOCK_OK, GTK_RESPONSE_OK,
						NULL);
	
	pTable = gtk_table_new(1, 2, FALSE);
	
	pLabel = gtk_label_new("Nom : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 0, 1);
	
	pEntry = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(pEntry), Name);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pEntry, 1, 2, 0, 1);
	
	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(pDialog)->vbox), pTable, TRUE, FALSE, 0);
	
	/* Affichage des elements de la boite de dialogue */
	gtk_widget_show_all(GTK_DIALOG(pDialog)->vbox);
	
	/* On lance la boite de dialogue et on recupere la reponse */
	switch (gtk_dialog_run(GTK_DIALOG(pDialog))){
		case GTK_RESPONSE_OK:
			NameModify = gtk_entry_get_text(GTK_ENTRY(pEntry));
			
			modifyCategoryToMagasin(pPreferencesData->pGlda->pMagasin, (gchar*)NameModify, idCat+1);
			modifyCategoryToInterface(pPreferencesData, (gchar*)NameModify, idCat);
			
			pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
			xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8" ,1);
			
			g_free(pFicXml);
			gtk_widget_destroy(pDialog);
			break;
		case GTK_RESPONSE_CANCEL:
			gtk_widget_destroy(pDialog);
			break;
		default:
			gtk_widget_destroy(pDialog);
			break;
	}
	g_free(Name);
}

void editSSCategory(Preferences *pPreferencesData, gint idCat, gint idSSCat){
	GtkWidget *pDialog;
	GtkWidget *pTable;
	GtkWidget *pLabel;
	GtkWidget *pEntry;
	gchar *Name = NULL;
	const gchar *NameModify;
	gchar *pFicXml;
	
	Name = getSousCategoryByCategory(pPreferencesData->pGlda->pMagasin, idCat+1, idSSCat+1);
	
	/* Creation de la boite de dialogue */
	pDialog = gtk_dialog_new_with_buttons("Modifier la sous-catégorie",
						GTK_WINDOW(pPreferencesData->pGlda->pWindow),
						GTK_DIALOG_MODAL,
						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
						GTK_STOCK_OK, GTK_RESPONSE_OK,
						NULL);
	
	pTable = gtk_table_new(1, 2, FALSE);
	
	pLabel = gtk_label_new("Nom : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 0, 1);
	
	pEntry = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(pEntry), Name);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pEntry, 1, 2, 0, 1);
	
	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(pDialog)->vbox), pTable, TRUE, FALSE, 0);
	
	/* Affichage des elements de la boite de dialogue */
	gtk_widget_show_all(GTK_DIALOG(pDialog)->vbox);
	
	/* On lance la boite de dialogue et on recupere la reponse */
	switch (gtk_dialog_run(GTK_DIALOG(pDialog))){
		case GTK_RESPONSE_OK:
			NameModify = gtk_entry_get_text(GTK_ENTRY(pEntry));
			
			modifySSCategoryToMagasin(pPreferencesData->pGlda->pMagasin, (gchar*)NameModify, idCat+1, idSSCat+1);
			modifySSCategoryToInterface(pPreferencesData, (gchar*)NameModify, idCat, idSSCat);
			
			pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
			xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8" ,1);
			
			g_free(pFicXml);
			gtk_widget_destroy(pDialog);
			break;
		case GTK_RESPONSE_CANCEL:
			gtk_widget_destroy(pDialog);
			break;
		default:
			gtk_widget_destroy(pDialog);
			break;
	}
	g_free(Name);
}

void editArticle(Preferences *pPreferencesData, gint idCat, gint idSSCat, gint idArt){
	GtkWidget *pDialog;
	GtkWidget *pTable;
	GtkWidget *pLabel;
	GtkWidget *pEntryName;
	GtkWidget *pEntryPrix;
	gchar *Name = NULL;
	gdouble PrixDouble;
	gchar *Prix = NULL;
	gchar *pPrix = NULL;
	const gchar *NameModify;
	const gchar *PrixModify;
	gchar *pFicXml;
	
	Name = getArticleNameBySousCategory(pPreferencesData->pGlda->pMagasin, idCat+1, idSSCat+1, idArt+1);
	Prix = getArticlePriceBySousCategory(pPreferencesData->pGlda->pMagasin, idCat+1, idSSCat+1, idArt+1);
	
	/* Creation de la boite de dialogue */
	pDialog = gtk_dialog_new_with_buttons("Modifier la sous-catégorie",
						GTK_WINDOW(pPreferencesData->pGlda->pWindow),
						GTK_DIALOG_MODAL,
						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
						GTK_STOCK_OK, GTK_RESPONSE_OK,
						NULL);
	
	pTable = gtk_table_new(2, 2, FALSE);
	
	pLabel = gtk_label_new("Nom : ");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 0, 1);
	
	pEntryName = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(pEntryName), Name);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pEntryName, 1, 2, 0, 1);
	
	pLabel = gtk_label_new("Prix :");
	gtk_table_attach_defaults(GTK_TABLE(pTable), pLabel, 0, 1, 1, 2);
	
	pEntryPrix = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(pEntryPrix), Prix);
	gtk_table_attach_defaults(GTK_TABLE(pTable), pEntryPrix, 1, 2, 1, 2);
	
	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(pDialog)->vbox), pTable, TRUE, FALSE, 0);
	
	/* Affichage des elements de la boite de dialogue */
	gtk_widget_show_all(GTK_DIALOG(pDialog)->vbox);
	
	/* On lance la boite de dialogue et on recupere la reponse */
	switch (gtk_dialog_run(GTK_DIALOG(pDialog))){
		case GTK_RESPONSE_OK:
			NameModify = gtk_entry_get_text(GTK_ENTRY(pEntryName));
			PrixModify = gtk_entry_get_text(GTK_ENTRY(pEntryPrix));
			
			PrixDouble = strtod(PrixModify, NULL);
			pPrix = g_strdup_printf("%.2f", PrixDouble);
			
			modifyArticleToMagasin(pPreferencesData->pGlda->pMagasin, (gchar*)NameModify, (gchar*)pPrix, idCat+1, idSSCat+1, idArt+1);
			modifyArticleToInterface(pPreferencesData, (gchar*)NameModify, (gchar*)pPrix, idCat, idSSCat, idArt);
			
			pFicXml = g_key_file_get_string(pPreferencesData->pGlda->pConfig, "file", "listeFile", NULL);
			xmlSaveFormatFileEnc(pFicXml, pPreferencesData->pGlda->pMagasin, "UTF-8" ,1);
			
			g_free(pFicXml);
			g_free(pPrix);
			gtk_widget_destroy(pDialog);
			break;
		case GTK_RESPONSE_CANCEL:
			gtk_widget_destroy(pDialog);
			break;
		default:
			gtk_widget_destroy(pDialog);
			break;
	}
	g_free(Name);
	g_free(Prix);
}

void modifyCategoryToInterface(Preferences *pPreferencesData, gchar *Name, gint idCat){
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(idCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	
	gtk_tree_store_set(pPreferencesData->pTreeStore, &Iter, PRODUITS_COLUMN, Name, PRIX_COLUMN, "", -1);
	
	pPath = gtk_tree_path_new_from_indices(idCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pGlda->pListCat), &Iter, pPath);
	
	gtk_tree_store_set(pPreferencesData->pGlda->pListCat, &Iter, MAGASINS_COLUMN, Name, -1);
	
	gtk_combo_box_remove_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1), idCat);
	gtk_combo_box_insert_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat1), idCat, Name);
	
	gtk_combo_box_remove_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2), idCat);
	gtk_combo_box_insert_text(GTK_COMBO_BOX(pPreferencesData->pComboBoxCat2), idCat, Name);
}

void modifySSCategoryToInterface(Preferences *pPreferencesData, gchar *Name, gint idCat, gint idSSCat){
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(idCat, idSSCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	
	gtk_tree_store_set(pPreferencesData->pTreeStore, &Iter, PRODUITS_COLUMN, Name, PRIX_COLUMN, "", -1);
	
	pPath = gtk_tree_path_new_from_indices(idCat, idSSCat, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pGlda->pListCat), &Iter, pPath);
	
	gtk_tree_store_set(pPreferencesData->pGlda->pListCat, &Iter, MAGASINS_COLUMN, Name, -1);
}

void modifyArticleToInterface(Preferences *pPreferencesData, gchar *Name, gchar *Prix, gint idCat, gint idSSCat, gint idArt){
	GtkTreeIter Iter;
	GtkTreePath *pPath;
	
	pPath = gtk_tree_path_new_from_indices(idCat, idSSCat, idArt, -1);
	gtk_tree_model_get_iter(GTK_TREE_MODEL(pPreferencesData->pTreeStore), &Iter, pPath);
	
	gtk_tree_store_set(pPreferencesData->pTreeStore, &Iter, PRODUITS_COLUMN, Name, PRIX_COLUMN, Prix, -1);
}

void modifyFileXml(Preferences *pPreferencesData){
	GtkWidget *pFileSelection;
	gchar *pChemin;
	Magasin pMagasin;
	
	/* Creation de la fenetre de selection */
    	pFileSelection = gtk_file_chooser_dialog_new("Selection le fichier Xml...",
    							GTK_WINDOW(pPreferencesData->pGlda->pWindow),
    							GTK_FILE_CHOOSER_ACTION_OPEN,
    							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
							GTK_STOCK_OPEN, GTK_RESPONSE_OK,
							NULL);
	
	/* Affichage fenetre */
	switch(gtk_dialog_run(GTK_DIALOG(pFileSelection))){
		case GTK_RESPONSE_OK:
			/* Recuperation du chemin */
			pChemin = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(pFileSelection));
			pMagasin = initMagasin(pChemin);
			if(pMagasin == NULL){
				errorDialog(pPreferencesData->pGlda, "Fichier Xml incorrect");
			}
			else{
				gtk_entry_set_text(GTK_ENTRY(pPreferencesData->pEntryListe), pChemin);
				freeMagasin(pMagasin);
			}
			gtk_widget_destroy(pFileSelection);
			g_free(pChemin);
			break;
		case GTK_RESPONSE_CANCEL:
			gtk_widget_destroy(pFileSelection);
			break;
		default:
			gtk_widget_destroy(pFileSelection);
			break;
	}
}
