/*
	printCallbacks.c
	By Tuxgasy <tuxgasy@tuxfamily.org>
	
	This file is part of Glda.
	
	You may redistribute it and/or modify it under the terms of the
	GNU General Public License, as published by the Free Software
	Foundation; either version 2 of the License, or (at your option) any later version.
	
	Glda is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
	See the GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with Glda; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <libxml/tree.h>
#include <libxml/parser.h>
#include <libxml/xpath.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <math.h>

#include "main.h"
#include "interface.h"

void begin_print(GtkPrintOperation *operation, GtkPrintContext *context, Print *pPrintData){
	gchar *contents;
	gdouble height;
	gsize length;
	
	g_file_get_contents(pPrintData->filename, &contents, &length, NULL);
	pPrintData->lines = g_strsplit(contents, "\n", 0);
	
	pPrintData->total_lines = 0;
	while(pPrintData->lines[pPrintData->total_lines] != NULL){
		pPrintData->total_lines++;
	}
	
	height = gtk_print_context_get_height(context) - HEADER_HEIGHT - HEADER_GAP;
	pPrintData->lines_per_page = floor(height/(pPrintData->font_size+3));
	pPrintData->total_pages = (pPrintData->total_lines - 1) / pPrintData->lines_per_page + 1;
	gtk_print_operation_set_n_pages(operation, pPrintData->total_pages);
	g_free(contents);
}

void draw_page(GtkPrintOperation *operation, GtkPrintContext *context, gint page_nr, Print *pPrintData){
	cairo_t *cr;
	PangoLayout *layout;
	gdouble width, text_height;
	gint line, i, text_width, layout_height;
	PangoFontDescription *desc;
	gchar *page_str;
	
	cr = gtk_print_context_get_cairo_context(context);
	width = gtk_print_context_get_width(context);
	layout = gtk_print_context_create_pango_layout(context);
	desc = pango_font_description_from_string("Monospace");
	pango_font_description_set_size(desc, pPrintData->font_size *PANGO_SCALE);
	
	pango_layout_set_font_description(layout, desc);
	pango_layout_set_text(layout, ""/*pPrintData->filename*/, -1);
	pango_layout_set_width(layout, -1);
	pango_layout_set_alignment(layout, PANGO_ALIGN_LEFT);
	pango_layout_get_size(layout, NULL, &layout_height);
	text_height = (gdouble)layout_height / PANGO_SCALE;
	
	cairo_move_to(cr, 0, (HEADER_HEIGHT - text_height) / 2);
	pango_cairo_show_layout(cr, layout);
	
	page_str = g_strdup_printf("%d / %d", page_nr+1, pPrintData->total_pages);
	pango_layout_set_text(layout, page_str, -1);
	pango_layout_get_size(layout, &text_width, NULL);
	pango_layout_set_alignment(layout, PANGO_ALIGN_RIGHT);
	
	cairo_move_to(cr, width - (text_width / PANGO_SCALE), (HEADER_HEIGHT - text_height) / 2);
	pango_cairo_show_layout(cr, layout);
	
	cairo_move_to(cr, 0, HEADER_HEIGHT + HEADER_GAP);
	line = page_nr * pPrintData->lines_per_page;
	for(i=0;i<pPrintData->lines_per_page && line<pPrintData->total_lines;i++){
		pango_layout_set_text(layout, pPrintData->lines[line], -1);
		pango_cairo_show_layout(cr, layout);
		cairo_rel_move_to(cr, 0, pPrintData->font_size + 3);
		line++;
	}
	
	g_free(page_str);
	g_object_unref(layout);
	pango_font_description_free(desc);
}

void end_print(GtkPrintOperation *operation, GtkPrintContext *context, Print *pPrintData){
	g_strfreev(pPrintData->lines);
}
